'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
var vue$1 = require('@headlessui/vue');
var vue3Dropzone = require('vue3-dropzone');
var axios = require('axios');
var Popper = require('vue3-popper');
var macrameVue3 = require('@macramejs/macrame-vue3');
var vCalendar = require('v-calendar');
require('v-calendar/dist/style.css');
var Draggable = require('vuedraggable');
var pageBuilderVue3 = require('@macramejs/page-builder-vue3');
var inertiaVue3 = require('@inertiajs/inertia-vue3');
var adminVue3 = require('@macramejs/admin-vue3');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e["default"] : e; }

var axios__default = /*#__PURE__*/_interopDefaultLegacy(axios);
var Popper__default = /*#__PURE__*/_interopDefaultLegacy(Popper);
var Draggable__default = /*#__PURE__*/_interopDefaultLegacy(Draggable);

function getVariant(props, { DEFAULT = 'primary' }) {
    return vue.computed(() => {
        if (props.variant) {
            return props.variant;
        }

        if (props.primary) {
            return 'primary';
        }
        if (props.secondary) {
            return 'secondary';
        }
        if (props.small) {
            return 'small';
        }
        if (props.text) {
            return 'text';
        }
        if (props.round) {
            return 'round';
        }
        if (props.blue) {
            return 'blue';
        }
        if (props.gray) {
            return 'gray';
        }
        if (props.green) {
            return 'green';
        }
        if (props.success) {
            return 'success';
        }
        if (props.yellow) {
            return 'yellow';
        }
        if (props.warning) {
            return 'warning';
        }
        if (props.red) {
            return 'red';
        }
        if (props.danger) {
            return 'danger';
        }
        if (props.purple) {
            return 'purple';
        }
        if (props.orange) {
            return 'orange';
        }
        if (props.darkorange) {
            return 'darkorange';
        }
        if (props.lightorange) {
            return 'lightorange';
        }
        if (props.grasgreen) {
            return 'grasgreen';
        }
        if (props.turkise) {
            return 'turkise';
        }
        if (props.lightblue) {
            return 'lightblue';
        }
        if (props.pink) {
            return 'pink';
        }

        return DEFAULT;
    });
}

const variants = {
    variant: {
        type: String,
        default: null,
    },
    blue: {
        type: Boolean,
        default: false,
    },
    primary: {
        type: Boolean,
        default: false,
    },
    secondary: {
        type: Boolean,
        default: false,
    },
    small: {
        type: Boolean,
        default: false,
    },
    text: {
        type: Boolean,
        default: false,
    },
    round: {
        type: Boolean,
        default: false,
    },
    gray: {
        type: Boolean,
        default: false,
    },
    green: {
        type: Boolean,
        default: false,
    },
    success: {
        type: Boolean,
        default: false,
    },
    yellow: {
        type: Boolean,
        default: false,
    },
    warning: {
        type: Boolean,
        default: false,
    },
    red: {
        type: Boolean,
        default: false,
    },
    danger: {
        type: Boolean,
        default: false,
    },
    orange: {
        type: Boolean,
        default: false,
    },
    purple: {
        type: Boolean,
        default: false,
    },
    darkorange: {
        type: Boolean,
        default: false,
    },
    lightorange: {
        type: Boolean,
        default: false,
    },
    grasgreen: {
        type: Boolean,
        default: false,
    },
    turkise: {
        type: Boolean,
        default: false,
    },
    lightblue: {
        type: Boolean,
        default: false,
    },
    pink: {
        type: Boolean,
        default: false,
    },
};

function getSize(props, { DEFAULT = 'md', only = ['sm', 'md', 'lg'] }) {
    return vue.computed(() => {
        if (props.size) {
            return props.size;
        }

        if (props.sm && only.includes('sm')) {
            return 'sm';
        }
        if (props.md && only.includes('md')) {
            return 'md';
        }
        if (props.lg && only.includes('lg')) {
            return 'lg';
        }

        return DEFAULT;
    });
}

const sizes = {
    size: {
        type: String,
        default: null,
    },
    sm: {
        type: Boolean,
        default: false,
    },
    md: {
        type: Boolean,
        default: false,
    },
    lg: {
        type: Boolean,
        default: false,
    },
};

var script$P = vue.defineComponent({
    props: {
        disabled: {
            default: false,
            type: Boolean,
        },
        text: {
            default: false,
            type: Boolean,
        },
        square: {
            default: false,
            type: Boolean,
        },
        outline: {
            default: false,
            type: Boolean,
        },
        ...variants,
        ...sizes,
    },
    setup(props, { attrs }) {
        const tag = 'href' in attrs ? 'a' : 'button';
        const variant_ = getVariant(props, {});
        const size_ = getSize(props, {});
        return { tag, variant_, size_ };
    },
});

function render$q(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(_ctx.tag), vue.mergeProps({
    class: ["relative inline-flex items-center justify-center text-sm uppercase transition-all duration-300 focus:ring focus:outline-none", {
            'focus:ring-transparent': _ctx.disabled,

            'w-[37px]': _ctx.square && _ctx.size_ == 'md',
            'w-[30px]': _ctx.square && _ctx.size_ == 'sm',

            'h-[37px]  rounded': _ctx.size_ == 'md' && !_ctx.text,
            'h-[30px]  rounded': _ctx.size_ == 'sm' && !_ctx.text,

            'px-5': _ctx.size_ == 'md' && !_ctx.square && !_ctx.text,
            'px-4': _ctx.size_ == 'sm' && !_ctx.square && !_ctx.text,

            'bg-gradient-to-r from-gradient-red-500 to-gradient-orange-500 hover:from-gradient-red-300 hover:to:gradient-orange-300 hover:scale-95 active:from-gradient-red-700 active:to-gradient-orange-700 text-white focus:ring-orange-100 shadow-orange shadow-primary':
                _ctx.variant_ == 'primary' && !_ctx.disabled,
            'bg-gray text-white cursor-not-allowed':
                _ctx.variant_ == 'primary' && _ctx.disabled,

            'bg-gradient-to-r w-[37px] h-[37px] rounded-full from-indigo-900 to-indigo-900 hover:from-gradient-red-500 hover:to-gradient-orange-500 hover:scale-95 active:from-indigo-500 active:to-indigo-500 text-white focus:ring-orange-100':
                _ctx.variant_ == 'round' && !_ctx.disabled,
            'bg-gray text-white rounded-full cursor-not-allowed':
                _ctx.variant_ == 'round' && _ctx.disabled,

            'bg-orange-500 bg-opacity-0 border border-indigo-900 hover:bg-opacity-20 hover:scale-95 active:bg-opacity-50 text-black focus:ring-orange-100':
                _ctx.variant_ == 'secondary' && !_ctx.disabled,
            'opacity-40 border border-indigo-900 cursor-not-allowed':
                _ctx.variant_ == 'secondary' && _ctx.disabled,

            'bg-gray-200 hover:bg-gray-500 h-[30px] active:bg-indigo-900 active:text-white text-black focus:ring-gray-300':
                _ctx.variant_ == 'small' && !_ctx.disabled,
            'opacity-40 cursor-not-allowed': _ctx.variant_ == 'small' && _ctx.disabled,

            'focus:rounded hover:border-indigo-500 h-[20px] py-3 px-2.5 after:absolute after:left-1/2 after:bottom-[3px] after:h-px after:w-[calc(100%-20px)] after:-translate-x-1/2 hover:after:bg-indigo-500 active:after:bg-indigo-500 text-black focus:ring-transparent focus:bg-orange-100':
                _ctx.variant_ == 'text' && !_ctx.disabled,
            'opacity-40 py-2 px-3 cursor-not-allowed':
                _ctx.variant_ == 'text' && _ctx.disabled,
        }],
    disabled: _ctx.disabled
  }, _ctx.$attrs), {
    default: vue.withCtx(() => [
      vue.renderSlot(_ctx.$slots, "default")
    ]),
    _: 3 /* FORWARDED */
  }, 16 /* FULL_PROPS */, ["class", "disabled"]))
}

script$P.render = render$q;
script$P.__file = "packages/admin-vue3/src/ui/Button.vue";

var script$O = vue.defineComponent({
    props: {
        as: {
            type: String,
            default: 'div',
        },
        variant: variants.variant,
        white: {
            type: Boolean,
            default: false,
        },
        gray: variants.gray,
        size: sizes.size,
        sm: sizes.sm,
        md: sizes.md,
    },
    setup(props, { attrs }) {
        let variant_ = getVariant(props, { DEFAULT: 'white' });
        let size_ = getSize(props, { only: ['sm', 'md'] });
        return { variant_, size_ };
    },
});

function render$p(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(_ctx.as), {
    class: vue.normalizeClass(["rounded-sm p-6", {
            'bg-white shadow': _ctx.variant_ == 'white',
            'bg-gray-300': _ctx.variant_ == 'gray',
            'p-12': _ctx.size_ == 'md',
            'p-8': _ctx.size_ == 'sm',
        }])
  }, {
    default: vue.withCtx(() => [
      vue.renderSlot(_ctx.$slots, "default")
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["class"]))
}

script$O.render = render$p;
script$O.__file = "packages/admin-vue3/src/ui/Card.vue";

var script$N = {
    components: { Switch: vue$1.Switch, SwitchGroup: vue$1.SwitchGroup, SwitchLabel: vue$1.SwitchLabel },
    props: {
        label: {
            type: String,
            default: null,
        },
        disabled: {
            type: Boolean,
            default: false,
        },
        modelValue: {
            type: Boolean,
            default: false,
        },
        ...sizes,
        ...variants,
    },
    setup({ disabled, ...props }, { emit }) {
        const size_ = getSize(props, {});
        const variant_ = getVariant(props, {});
        const update = (value) => {
            if (disabled) {
                return;
            }
            emit('update:modelValue', value);
        };
        return { update, size_, variant_ };
    },
};

const _hoisted_1$E = { class: "inline-flex flex-col" };

function render$o(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_SwitchLabel = vue.resolveComponent("SwitchLabel");
  const _component_Switch = vue.resolveComponent("Switch");
  const _component_SwitchGroup = vue.resolveComponent("SwitchGroup");

  return (vue.openBlock(), vue.createBlock(_component_SwitchGroup, null, {
    default: vue.withCtx(() => [
      vue.createElementVNode("div", _hoisted_1$E, [
        vue.createVNode(_component_SwitchLabel, { class: "mr-4" }, {
          default: vue.withCtx(() => [
            vue.renderSlot(_ctx.$slots, "default", {}, () => [
              vue.createTextVNode(vue.toDisplayString($props.label), 1 /* TEXT */)
            ])
          ]),
          _: 3 /* FORWARDED */
        }),
        vue.createVNode(_component_Switch, {
          modelValue: $props.modelValue,
          "onUpdate:modelValue": $setup.update,
          class: vue.normalizeClass([{
                    'bg-gray-500': !$props.modelValue,
                    'bg-green':
                        ($setup.variant_ == null && $props.modelValue) ||
                        ($setup.variant_ == 'primary' && $props.modelValue),

                    'text-lg': $setup.size_ == 'lg',
                    'text-base': $setup.size_ == 'md' || $setup.size_ == null,
                    'text-xs': $setup.size_ == 'sm',

                    'w-16': $setup.size_ == 'lg',
                    'w-[35px]': $setup.size_ == 'md' || $setup.size_ == null,
                    'w-8': $setup.size_ == 'sm',

                    'h-8 rounded-lg': $setup.size_ == 'lg',
                    'h-5 rounded-md': $setup.size_ == 'md' || $setup.size_ == null,
                    'h-4 rounded-sm': $setup.size_ == 'sm',
                }, "relative inline-flex items-center transition-all rounded-full focus:outline-none focus:ring-4 focus:ring-orange-100"])
        }, {
          default: vue.withCtx(() => [
            vue.createElementVNode("span", {
              class: vue.normalizeClass([{
                        'w-[26px] h-[26px]': $setup.size_ == 'lg',
                        'w-3.5 h-3.5': $setup.size_ == 'md',
                        'w-2.5 h-2.5': $setup.size_ == 'sm',

                        'translate-x-[34px]': $setup.size_ == 'lg' && $props.modelValue,
                        'translate-x-[4px]':
                            ($setup.size_ == 'md' && !$props.modelValue) ||
                            (!$props.modelValue),
                        'translate-x-[17px]': $setup.size_ == 'md' && $props.modelValue,
                        'translate-x-1': $setup.size_ == 'sm' && !$props.modelValue,
                        'translate-x-[18px]': $setup.size_ == 'sm' && $props.modelValue,
                    }, "inline-block transition-all transform bg-white rounded-full"])
            }, null, 2 /* CLASS */)
          ]),
          _: 1 /* STABLE */
        }, 8 /* PROPS */, ["modelValue", "onUpdate:modelValue", "class"])
      ])
    ]),
    _: 3 /* FORWARDED */
  }))
}

script$N.render = render$o;
script$N.__file = "packages/admin-vue3/src/ui/Toggle.vue";

var script$M = {
    components: { Switch: vue$1.Switch, SwitchGroup: vue$1.SwitchGroup, SwitchLabel: vue$1.SwitchLabel },
    props: {
        label: {
            type: String,
            default: null,
        },
        disabled: {
            type: Boolean,
            default: false,
        },
        modelValue: {
            type: Boolean,
            default: false,
        },
    },
    setup({ disabled }, { emit }) {
        const update = value => {
            if (disabled) {
                return;
            }
            emit('update:modelValue', value);
        };
        return { update };
    },
};

const _hoisted_1$D = ["disabled"];
const _hoisted_2$w = { class: "inline-block" };

function render$n(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createElementBlock("button", {
    onClick: _cache[0] || (_cache[0] = $event => ($setup.update(!$props.modelValue))),
    class: vue.normalizeClass(["h-[30px] px-3 py-2 flex items-center gap-2 transition-colors focus:outline-none duration-200 rounded-full leading-none text-sm", {
            'bg-gray-200 hover:bg-gray-300 text-gray-900 focus:bg-gray-300 active:bg-orange-100':
                !$props.modelValue && !$props.disabled,
            'bg-orange-100 text-orange-700': $props.modelValue && !$props.disabled,
            'bg-gray-100 text-gray-500 cursor-not-allowed': $props.disabled,
        }]),
    disabled: $props.disabled
  }, [
    vue.createElementVNode("span", _hoisted_2$w, vue.toDisplayString($props.label), 1 /* TEXT */)
  ], 10 /* CLASS, PROPS */, _hoisted_1$D))
}

script$M.render = render$n;
script$M.__file = "packages/admin-vue3/src/ui/Chip.vue";

var script$L = vue.defineComponent({
    name: 'FileUpload',
    emits: ['success', 'failed'],
    props: {
        modelValue: Array,
        accept: {
            type: [Array, String],
            default: null,
        },
        disabled: {
            type: Boolean,
            default: false,
        },
        inline: {
            type: Boolean,
            default: false,
        },
        maxSize: {
            type: Number,
            default: 10,
        },
        maxFiles: {
            type: Number,
            default: 1,
        },
        url: {
            type: String,
            required: true,
        },
        multiple: {
            type: Boolean,
            default: false,
        },
    },
    setup(props, { emit }) {
        const busy = vue.ref(false);
        const saveFiles = files => {
            busy.value = true;
            const formData = new FormData(); // pass data as a form
            for (var x = 0; x < files.length; x++) {
                // append files as array to the form, feel free to change the array name
                formData.append('files[]', files[x]);
            }
            // post the formData to your backend where storage is processed. In the backend, you will need to loop through the array and save each file through the loop.
            axios__default
                .post(props.url, formData, {
                headers: {
                    'Content-Type': 'multipart/form-data',
                },
            })
                .then(response => {
                console.info(response.data);
                busy.value = false;
                if (response.status >= 200 && response.status < 300) {
                    emit('success');
                }
            })
                .catch(err => {
                const error = new Error(err);
                console.error(error);
                busy.value = false;
                emit('failed', error);
            });
        };
        function onDrop(acceptFiles, rejectReasons) {
            if (rejectReasons.length == 0) {
                saveFiles(acceptFiles);
            }
        }
        const maxSize = vue.computed(() => {
            return props.maxSize * (1024 * 1024);
        });
        const { getRootProps, getInputProps, ...rest } = vue3Dropzone.useDropzone({
            onDrop,
            accept: props.accept,
            disabled: props.disabled,
            maxSize: maxSize.value,
            multiple: props.multiple,
            maxFiles: props.maxFiles,
        });
        return {
            getRootProps,
            getInputProps,
            ...rest,
        };
    },
});

const _hoisted_1$C = { class: "w-full" };
const _hoisted_2$v = /*#__PURE__*/vue.createElementVNode("div", { class: "text-orange" }, [
  /*#__PURE__*/vue.createElementVNode("svg", {
    width: "24",
    height: "24",
    "stroke-width": "1",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, [
    /*#__PURE__*/vue.createElementVNode("path", {
      d: "M13 21H3.6a.6.6 0 0 1-.6-.6V3.6a.6.6 0 0 1 .6-.6h16.8a.6.6 0 0 1 .6.6V13",
      stroke: "currentColor",
      "stroke-linecap": "round",
      "stroke-linejoin": "round"
    }),
    /*#__PURE__*/vue.createElementVNode("path", {
      d: "m3 16 7-3 5.5 2.5M16 10a2 2 0 1 1 0-4 2 2 0 0 1 0 4ZM16 19h3m3 0h-3m0 0v-3m0 3v3",
      stroke: "currentColor",
      "stroke-linecap": "round",
      "stroke-linejoin": "round"
    })
  ])
], -1 /* HOISTED */);
const _hoisted_3$n = {
  key: 0,
  class: "text-sm text-center uppercase"
};
const _hoisted_4$i = {
  key: 1,
  class: "text-sm text-center uppercase"
};
const _hoisted_5$a = {
  key: 2,
  class: "text-sm text-center uppercase"
};
const _hoisted_6$5 = {
  key: 0,
  class: "ml-[18px]"
};
const _hoisted_7$4 = { class: "inline-block mt-1 text-xs text-red-signal" };

function render$m(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createElementBlock(vue.Fragment, null, [
    vue.createElementVNode("div", _hoisted_1$C, [
      vue.createElementVNode("div", vue.mergeProps({
        class: ["flex items-center px-[18px] justify-center w-full h-40 transition-colors duration-300 border rounded cursor-pointer bg-gray-transparent focus:outline-none focus:border-orange", {
                'border-red-signal': _ctx.fileRejections.length > 0 || _ctx.isDragReject,
                'border-green': _ctx.isDragAccept,
                '!cursor-not-allowed': _ctx.disabled,
                'border-gray-200':
                    !_ctx.isDragReject &&
                    !_ctx.isDragAccept &&
                    _ctx.fileRejections.length == 0,
                '!h-[60px] !justify-start': _ctx.inline,
            }]
      }, _ctx.getRootProps()), [
        vue.createElementVNode("input", vue.normalizeProps(vue.guardReactiveProps(_ctx.getInputProps())), null, 16 /* FULL_PROPS */),
        vue.createElementVNode("div", {
          class: vue.normalizeClass(["flex gap-2.5 items-center", { 'flex-col': !_ctx.inline }])
        }, [
          _hoisted_2$v,
          (_ctx.busy)
            ? (vue.openBlock(), vue.createElementBlock("span", _hoisted_3$n, "Loading ..."))
            : vue.createCommentVNode("v-if", true),
          (!_ctx.busy && _ctx.isDragActive)
            ? (vue.openBlock(), vue.createElementBlock("span", _hoisted_4$i, "Drop the files here ..."))
            : vue.createCommentVNode("v-if", true),
          (!_ctx.busy && !_ctx.isDragActive)
            ? (vue.openBlock(), vue.createElementBlock("span", _hoisted_5$a, " Drag & Drop or browse "))
            : vue.createCommentVNode("v-if", true)
        ], 2 /* CLASS */)
      ], 16 /* FULL_PROPS */)
    ]),
    (_ctx.fileRejections.length > 0)
      ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_6$5, [
          (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(_ctx.fileRejections[0].errors, (error) => {
            return (vue.openBlock(), vue.createElementBlock("span", _hoisted_7$4, vue.toDisplayString(error.message), 1 /* TEXT */))
          }), 256 /* UNKEYED_FRAGMENT */))
        ]))
      : vue.createCommentVNode("v-if", true)
  ], 64 /* STABLE_FRAGMENT */))
}

script$L.render = render$m;
script$L.__file = "packages/admin-vue3/src/ui/FileUpload.vue";

const _hoisted_1$B = { class: "h-[30px] px-3 py-2 flex w-fit items-center gap-2 transition-colors bg-orange-100 focus:outline-none text-orange duration-200 rounded-full leading-none text-sm" };
const _hoisted_2$u = { class: "inline-block" };
const _hoisted_3$m = ["onClick"];
const _hoisted_4$h = /*#__PURE__*/ vue.createElementVNode("path", { d: "M7.314 5.9l3.535-3.536A1 1 0 1 0 9.435.95L5.899 4.485 2.364.95A1 1 0 1 0 .95 2.364l3.535 3.535L.95 9.435a1 1 0 1 0 1.414 1.414l3.535-3.535 3.536 3.535a1 1 0 1 0 1.414-1.414L7.314 5.899z" }, null, -1 /* HOISTED */);
const _hoisted_5$9 = [
    _hoisted_4$h
];
const _hoisted_6$4 = ["placeholder"];
var script$K = /*#__PURE__*/ vue.defineComponent({
    props: {
        modelValue: {
            type: Array,
            default: [],
        },
        placeholder: {
            type: String,
            default: 'Ihre Eingabe',
        },
        errors: {
            type: [Array, String],
            default: null,
        },
    },
    emits: ['update:modelValue'],
    setup(__props, { emit }) {
        const props = __props;
        const chips = vue.ref(props.modelValue);
        const currentInput = vue.ref('');
        const saveChip = () => {
            if (currentInput.value.length == 0) {
                return;
            }
            if (chips.value.find((chip) => chip === currentInput.value)) {
                return;
            }
            chips.value.push(currentInput.value);
            currentInput.value = '';
        };
        const deleteChip = (index) => {
            chips.value.splice(index, 1);
        };
        const backspaceDelete = () => {
            currentInput.value === ''
                ? chips.value.splice(chips.value.length - 1)
                : chips.value;
        };
        vue.watch(chips.value, () => {
            emit('update:modelValue', chips.value);
        });
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", {
                class: vue.normalizeClass(["relative flex flex-wrap gap-2 py-2.5 px-[18px] overflow-y-auto border rounded-sm max-h-[126px]", {
                        'border-red-signal': __props.errors?.length > 0 || !!__props.errors,
                        'border-gray-900': __props.errors?.length == 0 || !__props.errors,
                    }])
            }, [
                (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(chips.value, (chip, i) => {
                    return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$B, [
                        vue.createElementVNode("span", _hoisted_2$u, vue.toDisplayString(chip), 1 /* TEXT */),
                        (vue.openBlock(), vue.createElementBlock("svg", {
                            onClick: ($event) => (deleteChip(i)),
                            class: "cursor-pointer",
                            xmlns: "http://www.w3.org/2000/svg",
                            viewBox: "-6 -6 24 24",
                            width: "16",
                            fill: "currentColor"
                        }, _hoisted_5$9, 8 /* PROPS */, _hoisted_3$m))
                    ]));
                }), 256 /* UNKEYED_FRAGMENT */)),
                vue.withDirectives(vue.createElementVNode("input", {
                    type: "text",
                    class: "w-full py-2.5 px-[18px] -my-2.5 -mx-[18px] bg-transparent text-base placeholder:text-gray-900 focus:outline-none",
                    placeholder: __props.placeholder,
                    "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => ((currentInput).value = $event)),
                    onKeypress: _cache[1] || (_cache[1] = vue.withKeys(($event) => (saveChip()), ["enter"])),
                    onKeydown: _cache[2] || (_cache[2] = vue.withKeys(($event) => (backspaceDelete()), ["delete"]))
                }, null, 40 /* PROPS, HYDRATE_EVENTS */, _hoisted_6$4), [
                    [vue.vModelText, currentInput.value]
                ])
            ], 2 /* CLASS */));
        };
    }
});

script$K.__file = "packages/admin-vue3/src/ui/ChipInput.vue";

const _hoisted_1$A = {
    key: 1,
    class: "bg-gray-200 p-0.5 z-10 rounded-[8px]"
};
const _hoisted_2$t = /*#__PURE__*/ vue.createElementVNode("svg", {
    width: "24",
    height: "24",
    "stroke-width": "1.5",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
}, [
    /*#__PURE__*/ vue.createElementVNode("path", {
        d: "M18 12.5a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1ZM12 12.5a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1ZM6 12.5a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1Z",
        fill: "currentColor",
        stroke: "currentColor",
        "stroke-linecap": "round",
        "stroke-linejoin": "round"
    })
], -1 /* HOISTED */);
const _hoisted_3$l = [
    _hoisted_2$t
];
const _hoisted_4$g = { class: "z-20 p-4 rounded-[8px] px-[14px] text-base py-[24px] min-w-[200px] text-white bg-indigo-900" };
var script$J = /*#__PURE__*/ vue.defineComponent({
    props: {
        customButton: {
            type: Boolean,
            default: false,
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(vue.unref(Popper__default), vue.mergeProps(_ctx.$attrs, {
                placement: "right-end",
                arrow: ""
            }), {
                content: vue.withCtx(() => [
                    vue.createElementVNode("div", _hoisted_4$g, [
                        vue.renderSlot(_ctx.$slots, "default")
                    ])
                ]),
                default: vue.withCtx(() => [
                    vue.createElementVNode("div", null, [
                        (__props.customButton)
                            ? vue.renderSlot(_ctx.$slots, "button", { key: 0 })
                            : vue.createCommentVNode("v-if", true),
                        (!__props.customButton)
                            ? (vue.openBlock(), vue.createElementBlock("button", _hoisted_1$A, _hoisted_3$l))
                            : vue.createCommentVNode("v-if", true)
                    ])
                ]),
                _: 3 /* FORWARDED */
            }, 16 /* FULL_PROPS */));
        };
    }
});

var e=[],t=[];function n(n,r){if(n&&"undefined"!=typeof document){var a,s=!0===r.prepend?"prepend":"append",d=!0===r.singleTag,i="string"==typeof r.container?document.querySelector(r.container):document.getElementsByTagName("head")[0];if(d){var u=e.indexOf(i);-1===u&&(u=e.push(i)-1,t[u]={}),a=t[u]&&t[u][s]?t[u][s]:t[u][s]=c();}else a=c();65279===n.charCodeAt(0)&&(n=n.substring(1)),a.styleSheet?a.styleSheet.cssText+=n:a.appendChild(document.createTextNode(n));}function c(){var e=document.createElement("style");if(e.setAttribute("type","text/css"),r.attributes)for(var t=Object.keys(r.attributes),n=0;n<t.length;n++)e.setAttribute(t[n],r.attributes[t[n]]);var a="prepend"===s?"afterbegin":"beforeend";return i.insertAdjacentElement(a,e),e}}

var css$5 = "\n#arrow::before {\n    background-color: #120f30 !important;\n}\n";
n(css$5,{});

script$J.__file = "packages/admin-vue3/src/ui/ContextMenu.vue";

var script$I = vue.defineComponent({
    props: {
        ...variants,
    },
    setup(props, { attrs }) {
        const tag = 'href' in attrs ? 'a' : 'div';
        const variant_ = getVariant(props, {});
        return { tag, variant_ };
    },
});

function render$l(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(_ctx.tag), {
    class: vue.normalizeClass(["inline-flex items-center justify-center px-3 py-2 text-xs font-medium rounded-full", {
            'bg-gradient-to-r from-red-500 to-orange-500 text-white ':
                _ctx.variant_ == 'primary',
            'bg-gray-800 text-gray': _ctx.variant_ == 'gray',
            'bg-darkorange text-darkorange bg-opacity-30':
                _ctx.variant_ == 'darkorange' || _ctx.variant_ == 'orange',
            'bg-lightorange text-lightorange bg-opacity-30':
                _ctx.variant_ == 'lightorange',
            'bg-grasgreen text-grasgreen bg-opacity-30':
                _ctx.variant_ == 'grasgreen' || _ctx.variant_ == 'green',
            'bg-turkise text-turkise bg-opacity-30': _ctx.variant_ == 'turkise',
            'bg-lightblue text-lightblue bg-opacity-30':
                _ctx.variant_ == 'lightblue',
            'bg-blue text-blue bg-opacity-30': _ctx.variant_ == 'blue',
            'bg-red-signal text-red-signal bg-opacity-30': _ctx.variant_ == 'red',
            'bg-purple text-purple bg-opacity-30': _ctx.variant_ == 'purple',
            'bg-pink text-pink bg-opacity-30': _ctx.variant_ == 'pink',
        }])
  }, {
    default: vue.withCtx(() => [
      vue.renderSlot(_ctx.$slots, "default")
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["class"]))
}

script$I.render = render$l;
script$I.__file = "packages/admin-vue3/src/ui/Badge.vue";

const _hoisted_1$z = { class: "text-sm font-medium" };
const _hoisted_2$s = ["innerHTML"];
var script$H = /*#__PURE__*/ vue.defineComponent({
    props: {
        color: {
            type: String,
            default: 'purple',
        },
        title: {
            type: String,
            required: true,
        },
        hint: {
            type: String,
            default: null,
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", {
                class: vue.normalizeClass(["flex bg-white cursor-pointer hover:ring-2 rounded-xs", {
                        'hover:ring-purple ': __props.color == 'purple',
                        'hover:ring-green ': __props.color == 'green',
                        'hover:ring-orange ': __props.color == 'orange',
                        'hover:ring-red ': __props.color == 'red',
                        'hover:ring-blue ': __props.color == 'blue',
                    }])
            }, [
                vue.createElementVNode("div", {
                    class: vue.normalizeClass(["flex items-center justify-center w-12 h-auto mr-3 bg-opacity-10 rounded-xs", {
                            'text-purple bg-purple ': __props.color == 'purple',
                            'text-green bg-green ': __props.color == 'green',
                            'text-orange bg-orange ': __props.color == 'orange',
                            'text-red bg-red ': __props.color == 'red',
                            'text-blue bg-blue ': __props.color == 'blue',
                        }])
                }, [
                    vue.renderSlot(_ctx.$slots, "default")
                ], 2 /* CLASS */),
                vue.createElementVNode("div", _hoisted_1$z, [
                    vue.createTextVNode(vue.toDisplayString(__props.title) + " ", 1 /* TEXT */),
                    (__props.hint)
                        ? (vue.openBlock(), vue.createElementBlock("div", {
                            key: 0,
                            class: "text-xs font-normal text-gray",
                            innerHTML: __props.hint
                        }, null, 8 /* PROPS */, _hoisted_2$s))
                        : vue.createCommentVNode("v-if", true)
                ])
            ], 2 /* CLASS */));
        };
    }
});

script$H.__file = "packages/admin-vue3/src/ui/Drawer.vue";

const _hoisted_1$y = { class: "w-full py-4 border-b border-gray-400" };
const _hoisted_2$r = ["innerHTML"];
const _hoisted_3$k = /*#__PURE__*/ vue.createElementVNode("svg", {
    width: "24",
    height: "24",
    "stroke-width": "1.5",
    viewBox: "0 0 24 24",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    class: "w-3 h-3"
}, [
    /*#__PURE__*/ vue.createElementVNode("path", {
        d: "M6 9L12 15L18 9",
        stroke: "currentColor",
        "stroke-linecap": "round",
        "stroke-linejoin": "round"
    })
], -1 /* HOISTED */);
const _hoisted_4$f = [
    _hoisted_3$k
];
var script$G = /*#__PURE__*/ vue.defineComponent({
    props: {
        title: {
            type: String,
            required: true,
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$y, [
                vue.createVNode(vue.unref(vue$1.Disclosure), { defaultOpen: "" }, {
                    default: vue.withCtx(({ open }) => [
                        vue.createVNode(vue.unref(vue$1.DisclosureButton), { class: "flex items-center justify-between w-full px-4 text-sm font-medium" }, {
                            default: vue.withCtx(() => [
                                vue.createElementVNode("div", { innerHTML: __props.title }, null, 8 /* PROPS */, _hoisted_2$r),
                                vue.createElementVNode("div", {
                                    class: vue.normalizeClass({
                                        'rotate-180': !open,
                                    })
                                }, _hoisted_4$f, 2 /* CLASS */)
                            ]),
                            _: 2 /* DYNAMIC */
                        }, 1024 /* DYNAMIC_SLOTS */),
                        vue.createVNode(vue.unref(vue$1.DisclosurePanel), { class: "px-4 pt-3" }, {
                            default: vue.withCtx(() => [
                                vue.renderSlot(_ctx.$slots, "default")
                            ]),
                            _: 3 /* FORWARDED */
                        })
                    ]),
                    _: 3 /* FORWARDED */
                })
            ]));
        };
    }
});

script$G.__file = "packages/admin-vue3/src/ui/DrawerSection.vue";

var script$F = /*#__PURE__*/ vue.defineComponent({
    props: {
        disabled: {
            type: Boolean,
            default: false,
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(vue.unref(vue$1.Tab), {
                disabled: __props.disabled,
                as: "template",
                class: "focus:outline-none"
            }, {
                default: vue.withCtx(({ selected, active }) => [
                    vue.createElementVNode("button", {
                        class: vue.normalizeClass(["px-3 py-1.5 focus:outline-none transition-colors duration-200 text-base font-medium cursor-pointer", {
                                'text-black bg-gray-200 border-b border-indigo-900': selected && !__props.disabled,
                                'bg-gray-50 border-b border-transparent focus:bg-gray-200 hover:bg-gray-200': !selected && !__props.disabled,
                                'bg-gray-50 border-b border-transparent text-gray-300 cursor-not-allowed': __props.disabled,
                            }])
                    }, [
                        vue.renderSlot(_ctx.$slots, "default")
                    ], 2 /* CLASS */)
                ]),
                _: 3 /* FORWARDED */
            }, 8 /* PROPS */, ["disabled"]));
        };
    }
});

script$F.__file = "packages/admin-vue3/src/ui/Tab.vue";

const _hoisted_1$x = { class: "flex-1" };
var script$E = /*#__PURE__*/ vue.defineComponent({
    props: {
        hasSidebar: {
            type: Boolean,
            default: false,
        },
        sidebarTopPosition: {
            type: String,
            default: '118',
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(vue.unref(vue$1.TabPanel), { class: "relative flex justify-between w-full" }, {
                default: vue.withCtx(() => [
                    vue.createElementVNode("div", _hoisted_1$x, [
                        vue.renderSlot(_ctx.$slots, "default")
                    ]),
                    (__props.hasSidebar)
                        ? (vue.openBlock(), vue.createElementBlock("div", {
                            key: 0,
                            class: "w-[233px] sticky bg-white shadow",
                            style: vue.normalizeStyle(`height: calc(100vh - ${__props.sidebarTopPosition}px); top: ${__props.sidebarTopPosition}px;`)
                        }, [
                            vue.renderSlot(_ctx.$slots, "sidebar")
                        ], 4 /* STYLE */))
                        : vue.createCommentVNode("v-if", true)
                ]),
                _: 3 /* FORWARDED */
            }));
        };
    }
});

script$E.__file = "packages/admin-vue3/src/ui/TabPanel.vue";

const _hoisted_1$w = { class: "w-full" };
var script$D = /*#__PURE__*/ vue.defineComponent({
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$w, [
                vue.createVNode(vue.unref(vue$1.TabGroup), null, {
                    default: vue.withCtx(() => [
                        vue.renderSlot(_ctx.$slots, "default")
                    ]),
                    _: 3 /* FORWARDED */
                })
            ]));
        };
    }
});

script$D.__file = "packages/admin-vue3/src/ui/TabGroup.vue";

var script$C = /*#__PURE__*/ vue.defineComponent({
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(vue.unref(vue$1.TabList), { class: "flex flex-wrap sticky z-[5] bg-gray-50 top-[80px] w-full px-10 border-b border-gray-200" }, {
                default: vue.withCtx(() => [
                    vue.renderSlot(_ctx.$slots, "default")
                ]),
                _: 3 /* FORWARDED */
            }));
        };
    }
});

script$C.__file = "packages/admin-vue3/src/ui/TabList.vue";

var script$B = /*#__PURE__*/ vue.defineComponent({
    setup(__props) {
        //
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("form", vue.normalizeProps(vue.guardReactiveProps(_ctx.$attrs)), [
                vue.renderSlot(_ctx.$slots, "default")
            ], 16 /* FULL_PROPS */));
        };
    }
});

script$B.__file = "packages/admin-vue3/src/ui/Form.vue";

const _hoisted_1$v = { class: "inline-block mb-[14px]" };
var script$A = /*#__PURE__*/ vue.defineComponent({
    props: {
        label: {
            type: String,
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("span", _hoisted_1$v, [
                vue.renderSlot(_ctx.$slots, "default", {}, () => [
                    vue.createTextVNode(vue.toDisplayString(__props.label), 1 /* TEXT */)
                ])
            ]));
        };
    }
});

script$A.__file = "packages/admin-vue3/src/ui/FormFieldLabel.vue";

const _hoisted_1$u = { class: "todo" };
const _hoisted_2$q = {
    key: 1,
    class: "mt-1 text-xs text-right text-gray-500"
};
const _hoisted_3$j = {
    key: 2,
    class: "text-right"
};
var script$z = /*#__PURE__*/ vue.defineComponent({
    props: {
        label: {
            type: String,
        },
        errors: {
            type: [Array, String],
            default: null,
        },
        hint: {
            type: String,
        },
        noLabel: {
            type: Boolean,
            default: false,
        },
    },
    setup(__props) {
        const props = __props;
        const errorList = vue.computed(() => {
            if (!props.errors) {
                return [];
            }
            if (Array.isArray(props.errors)) {
                return props.errors;
            }
            return [props.errors];
        });
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$u, [
                (!__props.noLabel)
                    ? vue.renderSlot(_ctx.$slots, "label", { key: 0 }, () => [
                        vue.createVNode(script$A, { label: __props.label }, null, 8 /* PROPS */, ["label"])
                    ])
                    : vue.createCommentVNode("v-if", true),
                vue.renderSlot(_ctx.$slots, "default"),
                (__props.hint && !__props.errors)
                    ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_2$q, vue.toDisplayString(__props.hint), 1 /* TEXT */))
                    : vue.createCommentVNode("v-if", true),
                (__props.errors)
                    ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_3$j, [
                        (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(vue.unref(errorList), (error, key) => {
                            return (vue.openBlock(), vue.createElementBlock("span", {
                                key: key,
                                class: "inline-block mt-1 text-xs text-red"
                            }, vue.toDisplayString(error), 1 /* TEXT */));
                        }), 128 /* KEYED_FRAGMENT */))
                    ]))
                    : vue.createCommentVNode("v-if", true)
            ]));
        };
    }
});

script$z.__file = "packages/admin-vue3/src/ui/FormField.vue";

const _hoisted_1$t = { class: "fixed inset-0 z-50 overflow-y-auto" };
const _hoisted_2$p = { class: "min-h-screen px-4 text-center" };
const _hoisted_3$i = /*#__PURE__*/ vue.createElementVNode("span", {
    class: "inline-block h-screen align-middle",
    "aria-hidden": "true"
}, " ​ ", -1 /* HOISTED */);
var script$y = /*#__PURE__*/ vue.defineComponent({
    props: {
        open: {
            type: Boolean,
            default: false,
        },
        ...sizes,
    },
    emits: ['close', 'update:open'],
    setup(__props, { emit }) {
        const props = __props;
        const size_ = getSize(props, { DEFAULT: null });
        const close = (val) => {
            emit('close', val);
            emit('update:open', val);
        };
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(vue.unref(vue$1.TransitionRoot), {
                appear: "",
                show: __props.open,
                as: "template"
            }, {
                default: vue.withCtx(() => [
                    vue.createVNode(vue.unref(vue$1.Dialog), {
                        as: "div",
                        open: __props.open,
                        onClose: close
                    }, {
                        default: vue.withCtx(() => [
                            vue.createElementVNode("div", _hoisted_1$t, [
                                vue.createElementVNode("div", _hoisted_2$p, [
                                    vue.createVNode(vue.unref(vue$1.TransitionChild), {
                                        as: "template",
                                        enter: "duration-300 ease-out",
                                        "enter-from": "opacity-0",
                                        "enter-to": "opacity-100",
                                        leave: "duration-200 ease-in",
                                        "leave-from": "opacity-100",
                                        "leave-to": "opacity-0"
                                    }, {
                                        default: vue.withCtx(() => [
                                            vue.createVNode(vue.unref(vue$1.DialogOverlay), { class: "fixed inset-0 bg-gray-800 bg-opacity-75 backdrop-filter backdrop-blur-sm" })
                                        ]),
                                        _: 1 /* STABLE */
                                    }),
                                    _hoisted_3$i,
                                    vue.createVNode(vue.unref(vue$1.TransitionChild), {
                                        as: "template",
                                        enter: "duration-300 ease-out",
                                        "enter-from": "opacity-0 scale-95",
                                        "enter-to": "opacity-100 scale-100",
                                        leave: "duration-200 ease-in",
                                        "leave-from": "opacity-100 scale-100",
                                        "leave-to": "opacity-0 scale-95"
                                    }, {
                                        default: vue.withCtx(() => [
                                            vue.createElementVNode("div", {
                                                class: vue.normalizeClass(["inline-block w-full p-6 my-8 overflow-hidden text-left align-middle transition-all transform bg-white rounded shadow-xl", {
                                                        'max-w-full': !vue.unref(size_),
                                                        'max-w-3xl': vue.unref(size_) == 'lg',
                                                        'max-w-2xl': vue.unref(size_) == 'md',
                                                        'max-w-xl': vue.unref(size_) == 'sm',
                                                    }])
                                            }, [
                                                vue.renderSlot(_ctx.$slots, "default")
                                            ], 2 /* CLASS */)
                                        ]),
                                        _: 3 /* FORWARDED */
                                    })
                                ])
                            ])
                        ]),
                        _: 3 /* FORWARDED */
                    }, 8 /* PROPS */, ["open"])
                ]),
                _: 3 /* FORWARDED */
            }, 8 /* PROPS */, ["show"]));
        };
    }
});

script$y.__file = "packages/admin-vue3/src/ui/Modal.vue";

var script$x = vue.defineComponent({
    components: { Switch: vue$1.Switch },
    props: {
        label: {
            type: String,
            default: null,
        },
        disabled: {
            type: Boolean,
            default: false,
        },
        modelValue: {
            type: Boolean,
            default: false,
        },
        ...sizes,
        ...variants,
    },
    setup({ disabled, ...props }, { emit }) {
        const size_ = getSize(props, {});
        const variant_ = getVariant(props, {});
        const update = value => {
            if (disabled) {
                return;
            }
            emit('update:modelValue', value);
        };
        return { update, size_, variant_ };
    },
});

const _hoisted_1$s = { class: "inline-flex items-center cursor-pointer" };
const _hoisted_2$o = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M16.576.414a1.386 1.386 0 010 1.996l-9.404 9.176A1.461 1.461 0 016.149 12c-.37 0-.74-.139-1.023-.414L.424 6.998a1.386 1.386 0 010-1.996 1.47 1.47 0 012.046 0l3.68 3.59L14.53.414a1.47 1.47 0 012.046 0z",
  fill: "#120F30",
  "fill-rule": "nonzero"
}, null, -1 /* HOISTED */);
const _hoisted_3$h = [
  _hoisted_2$o
];
const _hoisted_4$e = { class: "pt-1 pl-2 cursor-pointer" };

function render$k(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Switch = vue.resolveComponent("Switch");

  return (vue.openBlock(), vue.createBlock(_component_Switch, {
    modelValue: _ctx.modelValue,
    "onUpdate:modelValue": _ctx.update,
    as: "template",
    class: "focus:outline-none"
  }, {
    default: vue.withCtx(({ checked }) => [
      vue.createElementVNode("div", _hoisted_1$s, [
        vue.createElementVNode("div", {
          class: vue.normalizeClass([
                    checked
                        ? 'bg-orange border-orange'
                        : 'bg-transparent border-indigo-900'
                , "z-0 flex items-center justify-center flex-shrink-0 w-[18px] h-[18px] mr-2 border rounded-xs focus:outline-none focus:ring-2 focus:ring-gray-300"])
        }, [
          (vue.openBlock(), vue.createElementBlock("svg", {
            class: vue.normalizeClass([checked ? 'block' : 'hidden', "z-0 w-2.5 h-2.5 text-gray-500 pointer-events-none fill-gray-500"]),
            viewBox: "0 0 17 12",
            xmlns: "http://www.w3.org/2000/svg"
          }, _hoisted_3$h, 2 /* CLASS */))
        ], 2 /* CLASS */),
        vue.createElementVNode("label", _hoisted_4$e, [
          vue.renderSlot(_ctx.$slots, "default", {}, () => [
            vue.createTextVNode(vue.toDisplayString(_ctx.label), 1 /* TEXT */)
          ])
        ])
      ])
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["modelValue", "onUpdate:modelValue"]))
}

script$x.render = render$k;
script$x.__file = "packages/admin-vue3/src/ui/CheckboxSwitch.vue";

const _withScopeId$2 = n => (vue.pushScopeId("data-v-c595bb9a"), n = n(), vue.popScopeId(), n);
const _hoisted_1$r = { class: "flex items-center cursor-pointer max-w-max" };
const _hoisted_2$n = ["checked", "id"];
const _hoisted_3$g = /*#__PURE__*/ _withScopeId$2(() => /*#__PURE__*/ vue.createElementVNode("path", {
    d: "M16.576.414a1.386 1.386 0 010 1.996l-9.404 9.176A1.461 1.461 0 016.149 12c-.37 0-.74-.139-1.023-.414L.424 6.998a1.386 1.386 0 010-1.996 1.47 1.47 0 012.046 0l3.68 3.59L14.53.414a1.47 1.47 0 012.046 0z",
    fill: "#120F30",
    "fill-rule": "nonzero"
}, null, -1 /* HOISTED */));
const _hoisted_4$d = [
    _hoisted_3$g
];
const _hoisted_5$8 = { class: "pl-1 cursor-pointer" };
var script$w = /*#__PURE__*/ vue.defineComponent({
    props: {
        value: {
            type: String,
            required: true,
        },
        label: {
            type: String,
        },
        fieldId: {
            type: String,
            required: true,
        },
        modelValue: {
            type: Array,
            required: true,
        },
    },
    emits: ['update:modelValue'],
    setup(__props, { emit }) {
        const props = __props;
        const checked = vue.computed(() => props.modelValue.includes(props.value));
        const check = () => {
            let updatedNames = [...props.modelValue];
            // remove name if checked, else add name
            if (checked.value) {
                updatedNames.splice(updatedNames.indexOf(props.value), 1);
            }
            else {
                updatedNames.push(props.value);
            }
            // emit the updated names
            emit('update:modelValue', updatedNames);
        };
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("label", _hoisted_1$r, [
                vue.createElementVNode("input", vue.mergeProps({
                    onInput: _cache[0] || (_cache[0] = ($event) => (check())),
                    type: "checkbox",
                    checked: vue.unref(checked),
                    id: __props.fieldId,
                    class: "absolute mr-2 opacity-0"
                }, _ctx.$attrs), null, 16 /* FULL_PROPS */, _hoisted_2$n),
                vue.createElementVNode("div", {
                    class: vue.normalizeClass([
                        vue.unref(checked)
                            ? 'bg-orange border-orange'
                            : 'bg-transparent border-indigo-900',
                        "z-0 flex items-center justify-center flex-shrink-0 w-[18px] h-[18px] mr-2 border rounded-xs"
                    ])
                }, [
                    (vue.openBlock(), vue.createElementBlock("svg", {
                        class: vue.normalizeClass([vue.unref(checked) ? 'block' : 'hidden', "z-0 w-2.5 h-2.5 text-gray-500 pointer-events-none fill-gray-500"]),
                        viewBox: "0 0 17 12",
                        xmlns: "http://www.w3.org/2000/svg"
                    }, _hoisted_4$d, 2 /* CLASS */))
                ], 2 /* CLASS */),
                vue.createElementVNode("div", _hoisted_5$8, [
                    vue.renderSlot(_ctx.$slots, "default", {}, () => [
                        vue.createTextVNode(vue.toDisplayString(__props.label ?? __props.value), 1 /* TEXT */)
                    ])
                ])
            ]));
        };
    }
});

var css$4 = "\ninput:focus + div[data-v-c595bb9a] {\n    box-shadow: 0px 0 0 4px #d6d8e2;\n}\n";
n(css$4,{});

script$w.__scopeId = "data-v-c595bb9a";
script$w.__file = "packages/admin-vue3/src/ui/Checkbox.vue";

var script$v = vue.defineComponent({
    components: {
        FormCheckboxes: macrameVue3.FormCheckboxes,
        FieldTitle: macrameVue3.FieldTitle,
    },
});

function render$j(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_field_title = vue.resolveComponent("field-title");
  const _component_form_checkboxes = vue.resolveComponent("form-checkboxes", true);

  return (vue.openBlock(), vue.createElementBlock("div", null, [
    vue.createVNode(_component_field_title, vue.normalizeProps(vue.guardReactiveProps(_ctx.$attrs)), null, 16 /* FULL_PROPS */),
    vue.createElementVNode("div", null, [
      vue.createVNode(_component_form_checkboxes, vue.normalizeProps(vue.guardReactiveProps(_ctx.$attrs)), null, 16 /* FULL_PROPS */)
    ])
  ]))
}

script$v.render = render$j;
script$v.__file = "packages/admin-vue3/src/ui/FormCheckboxes.vue";

const _withScopeId$1 = n => (vue.pushScopeId("data-v-a4e231ec"), n = n(), vue.popScopeId(), n);
const _hoisted_1$q = { class: "relative" };
const _hoisted_2$m = { class: "absolute top-0 left-0 right-0 flex w-full h-full max-w-full pointer-events-none" };
const _hoisted_3$f = /*#__PURE__*/ _withScopeId$1(() => /*#__PURE__*/ vue.createElementVNode("div", { class: "border-l input-section-1 border-t border-b border-gray-900 w-[16px] h-full rounded-l-[8px]" }, null, -1 /* HOISTED */));
const _hoisted_4$c = /*#__PURE__*/ _withScopeId$1(() => /*#__PURE__*/ vue.createElementVNode("div", { class: "border-r border-t input-section-3 border-b focus:border-orange border-gray-900 flex-grow rounded-r-[8px] h-full" }, null, -1 /* HOISTED */));
function setup(__props) {
    const focused = vue.ref(false);
    const id = `mcr-input-${Math.random() * 1000000}`;
    return (_ctx, _cache) => {
        return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$q, [
            vue.createVNode(vue.unref(macrameVue3.Input), vue.mergeProps(_ctx.$attrs, {
                id: id,
                disabled: __props.disabled,
                onFocus: _cache[0] || (_cache[0] = ($event) => (focused.value = true)),
                onBlur: _cache[1] || (_cache[1] = ($event) => (focused.value = false)),
                class: ["px-[18px] z-10 w-full transition-colors duration-200 bg-transparent focus:outline-none focus:input-focused text-indigo-900 py-2.5", {
                        'cursor-not-allowed': __props.disabled,
                        'has-errors': __props.errors.length > 0 && !__props.disabled,
                    }]
            }), null, 16 /* FULL_PROPS */, ["disabled", "class"]),
            vue.createElementVNode("div", _hoisted_2$m, [
                _hoisted_3$f,
                vue.createElementVNode("div", {
                    class: vue.normalizeClass(["relative h-full px-1 border-t border-b border-gray-900 input-width input-section-2", {
                            '!border-t-transparent': (_ctx.$attrs.modelValue?.length > 0 && __props.label) ||
                                (focused.value && __props.label),
                            'border-t-gray-900': _ctx.$attrs.modelValue?.length == 0 || !_ctx.$attrs.modelValue,
                        }])
                }, [
                    vue.createElementVNode("label", {
                        class: vue.normalizeClass(["relative inline-block text-sm transition duration-200 origin-left whitespace-nowrap will-change-auto h-fit top-1/2", {
                                'text-ellipsis !-translate-y-[35px] !scale-100 text-indigo-900': _ctx.$attrs.modelValue?.length > 0 || focused.value,
                                'max-w-full -translate-y-[13px] scale-[1.34] text-gray-900': _ctx.$attrs.modelValue?.length == 0 ||
                                    !_ctx.$attrs.modelValue,
                                '!text-red-signal': (_ctx.$attrs.modelValue?.length > 0 &&
                                    __props.errors.length > 0 &&
                                    !__props.disabled) ||
                                    (focused.value && __props.errors.length > 0 && !__props.disabled),
                            }]),
                        for: id
                    }, vue.toDisplayString(__props.label), 3 /* TEXT, CLASS */)
                ], 2 /* CLASS */),
                _hoisted_4$c
            ])
        ]));
    };
}
const __default__ = {
    inheritAttrs: false,
    customOptions: {},
};
var script$u = /*#__PURE__*/ vue.defineComponent({
    ...__default__,
    props: {
        label: {
            type: String,
            default: null,
        },
        hint: {
            type: String,
            default: null,
        },
        disabled: {
            type: Boolean,
            default: false,
        },
        errors: {
            type: Array,
            default: [],
        },
    },
    setup
});

var css$3 = "\ninput:focus + div > .input-section-1[data-v-a4e231ec] {\n    border-color: #fead5e;\n}\ninput:focus + div > .input-section-2[data-v-a4e231ec] {\n    border-bottom-color: #fead5e;\n    border-top-color: #fead5e;\n}\ninput:focus + div > .input-section-2 > label[data-v-a4e231ec] {\n    color: #fead5e;\n}\ninput:focus + div > .input-section-3[data-v-a4e231ec] {\n    border-color: #fead5e;\n}\n.input-width[data-v-a4e231ec] {\n    flex: 0 0 auto;\n    max-width: calc(100% - 12px * 2);\n}\n.input-width-focused[data-v-a4e231ec] {\n    max-width: calc(100% * 0.75);\n}\ninput.has-errors + div > .input-section-1[data-v-a4e231ec] {\n    border-color: #f74b6d;\n}\ninput.has-errors + div > .input-section-2[data-v-a4e231ec] {\n    border-bottom-color: #f74b6d;\n    border-top-color: #f74b6d;\n}\ninput.has-errors + div > .input-section-3[data-v-a4e231ec] {\n    border-color: #f74b6d;\n}\n";
n(css$3,{});

script$u.__scopeId = "data-v-a4e231ec";
script$u.__file = "packages/admin-vue3/src/ui/Input.vue";

var script$t = /*#__PURE__*/ vue.defineComponent({
    props: {
        label: {
            type: String,
            default: null,
        },
        hint: {
            type: String,
            default: null,
        },
        disabled: {
            type: Boolean,
            default: false,
        },
        errors: {
            type: Array,
            default: [],
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(vue.unref(vCalendar.DatePicker), vue.mergeProps(_ctx.$attrs, {
                class: "relative",
                "is-dark": "",
                color: "orange"
            }), {
                default: vue.withCtx(({ inputValue, inputEvents }) => [
                    vue.createVNode(script$u, vue.mergeProps({ modelValue: inputValue }, vue.toHandlers(inputEvents), {
                        errors: __props.errors,
                        label: __props.label
                    }), null, 16 /* FULL_PROPS */, ["modelValue", "errors", "label"])
                ]),
                _: 1 /* STABLE */
            }, 16 /* FULL_PROPS */));
        };
    }
});

script$t.__file = "packages/admin-vue3/src/ui/DatePicker.vue";

const _hoisted_1$p = { class: "flex items-center justify-center w-full" };
const _hoisted_2$l = { class: "relative w-full" };
const _hoisted_3$e = /*#__PURE__*/ vue.createElementVNode("svg", {
    class: "w-4 h-4 mx-2",
    fill: "none",
    viewBox: "0 0 24 24",
    stroke: "currentColor"
}, [
    /*#__PURE__*/ vue.createElementVNode("path", {
        "stroke-linecap": "round",
        "stroke-linejoin": "round",
        "stroke-width": "2",
        d: "M14 5l7 7m0 0l-7 7m7-7H3"
    })
], -1 /* HOISTED */);
const _hoisted_4$b = { class: "relative w-full" };
var script$s = /*#__PURE__*/ vue.defineComponent({
    props: {
        label: {
            type: String,
            default: null,
        },
        hint: {
            type: String,
            default: null,
        },
        disabled: {
            type: Boolean,
            default: false,
        },
        errors: {
            type: Array,
            default: [],
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(vue.unref(vCalendar.DatePicker), vue.mergeProps(_ctx.$attrs, {
                columns: 2,
                "is-range": "",
                "is-dark": "",
                color: "orange",
                class: "z-10 w-full"
            }), {
                default: vue.withCtx(({ inputValue, inputEvents }) => [
                    vue.createElementVNode("div", _hoisted_1$p, [
                        vue.createElementVNode("div", _hoisted_2$l, [
                            vue.createVNode(script$u, vue.mergeProps({
                                modelValue: inputValue.start,
                                errors: __props.errors
                            }, vue.toHandlers(inputEvents.start), { label: "Start" }), null, 16 /* FULL_PROPS */, ["modelValue", "errors"])
                        ]),
                        _hoisted_3$e,
                        vue.createElementVNode("div", _hoisted_4$b, [
                            vue.createVNode(script$u, vue.mergeProps({
                                modelValue: inputValue.end,
                                errors: __props.errors
                            }, vue.toHandlers(inputEvents.end), { label: "Ende" }), null, 16 /* FULL_PROPS */, ["modelValue", "errors"])
                        ])
                    ])
                ]),
                _: 1 /* STABLE */
            }, 16 /* FULL_PROPS */));
        };
    }
});

script$s.__file = "packages/admin-vue3/src/ui/DateRange.vue";

var script$r = vue.defineComponent({
    components: { RadioGroup: vue$1.RadioGroup, RadioGroupLabel: vue$1.RadioGroupLabel, RadioGroupOption: vue$1.RadioGroupOption },
    props: {
        labelKey: {
            type: String,
            default: null,
        },
        valueKey: {
            type: String,
            default: null,
        },
        disabledKey: {
            type: String,
            default: null,
        },
        options: {
            type: Array,
            default: () => [],
        },
        modelValue: {
            type: [String, Number],
            default: null,
        },
    },
    setup(props, { attrs }) {
        const optionValue = (option) => {
            if (props.valueKey === null) {
                return option;
            }
            return option[props.valueKey];
        };
        const optionLabel = (option) => {
            if (props.labelKey === null) {
                return option;
            }
            return option[props.labelKey];
        };
        const isDisabled = (option) => {
            if (props.disabledKey === null) {
                return false;
            }
            return option[props.disabledKey] == true;
        };
        return { optionValue, optionLabel, isDisabled };
    },
});

const _hoisted_1$o = { class: "flex gap-2" };
const _hoisted_2$k = { class: "flex" };

function render$i(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_RadioGroupLabel = vue.resolveComponent("RadioGroupLabel");
  const _component_RadioGroupOption = vue.resolveComponent("RadioGroupOption");
  const _component_RadioGroup = vue.resolveComponent("RadioGroup", true);

  return (vue.openBlock(), vue.createBlock(_component_RadioGroup, {
    modelValue: _ctx.modelValue,
    "onUpdate:modelValue": _cache[0] || (_cache[0] = $event => (_ctx.$emit('update:modelValue', $event)))
  }, {
    default: vue.withCtx(() => [
      vue.createCommentVNode(" <RadioGroupLabel>Plan</RadioGroupLabel> "),
      (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(_ctx.options, (option) => {
        return (vue.openBlock(), vue.createBlock(_component_RadioGroupOption, {
          as: "template",
          class: "mb-3 rounded focus:outline-none max-w-max focus:ring-4 focus:ring-orange-100",
          key: _ctx.optionValue(option),
          value: _ctx.optionValue(option),
          disabled: _ctx.isDisabled(option)
        }, {
          default: vue.withCtx(({ checked, disabled }) => [
            vue.createElementVNode("div", _hoisted_1$o, [
              vue.createElementVNode("div", _hoisted_2$k, [
                vue.createElementVNode("div", {
                  class: vue.normalizeClass(["flex items-center justify-center bg-white w-[18px] h-[18px] border rounded-lg", {
                            'border-orange': checked && !disabled,
                            'border-indigo-900': !checked && !disabled,
                            'border-gray-500': disabled,
                        }])
                }, [
                  vue.createElementVNode("div", {
                    class: vue.normalizeClass(["w-2.5 h-2.5 rounded-full", {
                                'bg-orange': checked,
                                'bg-white': !checked,
                            }])
                  }, null, 2 /* CLASS */)
                ], 2 /* CLASS */)
              ]),
              vue.createVNode(_component_RadioGroupLabel, {
                as: "p",
                class: vue.normalizeClass(["flex-1 mt-0.5 leading-none cursor-pointer", { 'text-gray-500': disabled }])
              }, {
                default: vue.withCtx(() => [
                  vue.createTextVNode(vue.toDisplayString(_ctx.optionLabel(option)), 1 /* TEXT */)
                ]),
                _: 2 /* DYNAMIC */
              }, 1032 /* PROPS, DYNAMIC_SLOTS */, ["class"])
            ])
          ]),
          _: 2 /* DYNAMIC */
        }, 1032 /* PROPS, DYNAMIC_SLOTS */, ["value", "disabled"]))
      }), 128 /* KEYED_FRAGMENT */))
    ]),
    _: 1 /* STABLE */
  }, 8 /* PROPS */, ["modelValue"]))
}

script$r.render = render$i;
script$r.__file = "packages/admin-vue3/src/ui/RadioGroup.vue";

var script$q = vue.defineComponent({
    components: { Button: script$P },
    props: {
        table: {
            type: Object,
            required: true,
        },
    },
});

const _hoisted_1$n = { class: "flex justify-around" };
const _hoisted_2$j = { class: "flex items-stretch space-x-2" };
const _hoisted_3$d = /*#__PURE__*/vue.createElementVNode("svg", {
  class: "absolute fill-current left-1",
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24",
  width: "24",
  height: "24"
}, [
  /*#__PURE__*/vue.createElementVNode("path", {
    fill: "none",
    d: "M0 0h24v24H0z"
  }),
  /*#__PURE__*/vue.createElementVNode("path", { d: "M10.828 12l4.95 4.95-1.414 1.414L8 12l6.364-6.364 1.414 1.414z" })
], -1 /* HOISTED */);
const _hoisted_4$a = /*#__PURE__*/vue.createElementVNode("svg", {
  class: "absolute fill-current right-1",
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24",
  width: "24",
  height: "24"
}, [
  /*#__PURE__*/vue.createElementVNode("path", {
    fill: "none",
    d: "M0 0h24v24H0z"
  }),
  /*#__PURE__*/vue.createElementVNode("path", { d: "M10.828 12l4.95 4.95-1.414 1.414L8 12l6.364-6.364 1.414 1.414z" })
], -1 /* HOISTED */);
const _hoisted_5$7 = /*#__PURE__*/vue.createElementVNode("svg", {
  class: "fill-current",
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24",
  width: "24",
  height: "24"
}, [
  /*#__PURE__*/vue.createElementVNode("path", {
    fill: "none",
    d: "M0 0h24v24H0z"
  }),
  /*#__PURE__*/vue.createElementVNode("path", { d: "M10.828 12l4.95 4.95-1.414 1.414L8 12l6.364-6.364 1.414 1.414z" })
], -1 /* HOISTED */);
const _hoisted_6$3 = { class: "flex items-center px-4 space-x-6 text-gray" };
const _hoisted_7$3 = {
  key: 0,
  class: "text-lg"
};
const _hoisted_8$2 = { class: "text-lg font-bold text-blue" };
const _hoisted_9$2 = {
  key: 5,
  class: "text-lg cursor-pointer"
};
const _hoisted_10 = /*#__PURE__*/vue.createElementVNode("svg", {
  class: "fill-current",
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24",
  width: "24",
  height: "24"
}, [
  /*#__PURE__*/vue.createElementVNode("path", {
    fill: "none",
    d: "M0 0h24v24H0z"
  }),
  /*#__PURE__*/vue.createElementVNode("path", { d: "M13.172 12l-4.95-4.95 1.414-1.414L16 12l-6.364 6.364-1.414-1.414z" })
], -1 /* HOISTED */);
const _hoisted_11 = /*#__PURE__*/vue.createElementVNode("svg", {
  class: "absolute fill-current right-1",
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24",
  width: "24",
  height: "24"
}, [
  /*#__PURE__*/vue.createElementVNode("path", {
    fill: "none",
    d: "M0 0h24v24H0z"
  }),
  /*#__PURE__*/vue.createElementVNode("path", { d: "M13.172 12l-4.95-4.95 1.414-1.414L16 12l-6.364 6.364-1.414-1.414z" })
], -1 /* HOISTED */);
const _hoisted_12 = /*#__PURE__*/vue.createElementVNode("svg", {
  class: "absolute fill-current left-1",
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24",
  width: "24",
  height: "24"
}, [
  /*#__PURE__*/vue.createElementVNode("path", {
    fill: "none",
    d: "M0 0h24v24H0z"
  }),
  /*#__PURE__*/vue.createElementVNode("path", { d: "M13.172 12l-4.95-4.95 1.414-1.414L16 12l-6.364 6.364-1.414-1.414z" })
], -1 /* HOISTED */);

function render$h(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Button = vue.resolveComponent("Button");

  return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$n, [
    vue.createElementVNode("div", _hoisted_2$j, [
      vue.createVNode(_component_Button, {
        secondary: "",
        square: "",
        class: "relative",
        onClick: _cache[0] || (_cache[0] = $event => (_ctx.table.setPage(1))),
        disabled: _ctx.table.currentPage == 1
      }, {
        default: vue.withCtx(() => [
          _hoisted_3$d,
          _hoisted_4$a
        ]),
        _: 1 /* STABLE */
      }, 8 /* PROPS */, ["disabled"]),
      vue.createVNode(_component_Button, {
        secondary: "",
        square: "",
        disabled: _ctx.table.currentPage == 1,
        onClick: _cache[1] || (_cache[1] = $event => (_ctx.table.setPage(_ctx.table.currentPage - 1)))
      }, {
        default: vue.withCtx(() => [
          _hoisted_5$7
        ]),
        _: 1 /* STABLE */
      }, 8 /* PROPS */, ["disabled"]),
      vue.createElementVNode("div", _hoisted_6$3, [
        (_ctx.table.currentPage > 2)
          ? (vue.openBlock(), vue.createElementBlock("span", _hoisted_7$3, " ... "))
          : vue.createCommentVNode("v-if", true),
        (
                        _ctx.table.currentPage == _ctx.table.getLastPage() &&
                        _ctx.table.currentPage > 2
                    )
          ? (vue.openBlock(), vue.createElementBlock("span", {
              key: 1,
              class: "text-lg cursor-pointer",
              onClick: _cache[2] || (_cache[2] = $event => (_ctx.table.setPage(_ctx.table.currentPage - 2)))
            }, vue.toDisplayString(_ctx.table.currentPage - 2), 1 /* TEXT */))
          : vue.createCommentVNode("v-if", true),
        (_ctx.table.currentPage > 1)
          ? (vue.openBlock(), vue.createElementBlock("span", {
              key: 2,
              class: "text-lg cursor-pointer",
              onClick: _cache[3] || (_cache[3] = $event => (_ctx.table.setPage(_ctx.table.currentPage - 1)))
            }, vue.toDisplayString(_ctx.table.currentPage - 1), 1 /* TEXT */))
          : vue.createCommentVNode("v-if", true),
        vue.createElementVNode("span", _hoisted_8$2, vue.toDisplayString(_ctx.table.currentPage), 1 /* TEXT */),
        (_ctx.table.currentPage < _ctx.table.getLastPage())
          ? (vue.openBlock(), vue.createElementBlock("span", {
              key: 3,
              class: "text-lg cursor-pointer",
              onClick: _cache[4] || (_cache[4] = $event => (_ctx.table.setPage(_ctx.table.currentPage + 1)))
            }, vue.toDisplayString(_ctx.table.currentPage + 1), 1 /* TEXT */))
          : vue.createCommentVNode("v-if", true),
        (_ctx.table.currentPage == 1 && _ctx.table.getLastPage() > 2)
          ? (vue.openBlock(), vue.createElementBlock("span", {
              key: 4,
              class: "text-lg cursor-pointer",
              onClick: _cache[5] || (_cache[5] = $event => (_ctx.table.setPage(_ctx.table.currentPage + 2)))
            }, vue.toDisplayString(_ctx.table.currentPage + 2), 1 /* TEXT */))
          : vue.createCommentVNode("v-if", true),
        (_ctx.table.currentPage < _ctx.table.getLastPage() - 1)
          ? (vue.openBlock(), vue.createElementBlock("span", _hoisted_9$2, " ... "))
          : vue.createCommentVNode("v-if", true)
      ]),
      vue.createVNode(_component_Button, {
        secondary: "",
        square: "",
        disabled: !(_ctx.table.currentPage < _ctx.table.getLastPage()),
        onClick: _cache[6] || (_cache[6] = $event => (_ctx.table.setPage(_ctx.table.currentPage + 1)))
      }, {
        default: vue.withCtx(() => [
          _hoisted_10
        ]),
        _: 1 /* STABLE */
      }, 8 /* PROPS */, ["disabled"]),
      vue.createVNode(_component_Button, {
        secondary: "",
        square: "",
        class: "relative",
        onClick: _cache[7] || (_cache[7] = $event => (_ctx.table.lastPage())),
        disabled: !(_ctx.table.currentPage < _ctx.table.getLastPage())
      }, {
        default: vue.withCtx(() => [
          _hoisted_11,
          _hoisted_12
        ]),
        _: 1 /* STABLE */
      }, 8 /* PROPS */, ["disabled"])
    ])
  ]))
}

script$q.render = render$h;
script$q.__file = "packages/admin-vue3/src/ui/Pagination.vue";

var script$p = vue.defineComponent({
    components: { BaseInput: macrameVue3.Input },
    props: {
        table: {
            type: Object,
            required: true,
        },
        placeholder: {
            type: String,
        },
    },
    setup() {
        //
    },
});

const _hoisted_1$m = { class: "flex items-center h-full max-w-sm mb-6 overflow-hidden text-gray-800 border border-gray-500 rounded focus-within:text-blue" };
const _hoisted_2$i = /*#__PURE__*/vue.createElementVNode("div", { class: "flex items-center justify-center w-10 h-10 text-gray-800 bg-gray-300" }, [
  /*#__PURE__*/vue.createElementVNode("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "-2.5 -2.5 24 24",
    width: "16",
    height: "16",
    preserveAspectRatio: "xMinYMin",
    class: "fill-gray-800 icon__icon"
  }, [
    /*#__PURE__*/vue.createElementVNode("path", { d: "M8 14A6 6 0 1 0 8 2a6 6 0 0 0 0 12zm6.32-1.094l3.58 3.58a1 1 0 1 1-1.415 1.413l-3.58-3.58a8 8 0 1 1 1.414-1.414z" })
  ])
], -1 /* HOISTED */);

function render$g(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_BaseInput = vue.resolveComponent("BaseInput");

  return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$m, [
    _hoisted_2$i,
    vue.createVNode(_component_BaseInput, {
      modelValue: _ctx.table.search,
      "onUpdate:modelValue": _cache[0] || (_cache[0] = $event => ((_ctx.table.search) = $event)),
      modelModifiers: { debounce: true },
      class: "w-full h-full pl-6 text-gray-800 bg-transparent outline-none placeholder:text-gray-500",
      placeholder: _ctx.placeholder
    }, null, 8 /* PROPS */, ["modelValue", "placeholder"])
  ]))
}

script$p.render = render$g;
script$p.__file = "packages/admin-vue3/src/ui/Search.vue";

var script$o = vue.defineComponent({
    components: {
        Pagination: script$q,
        Search: script$p,
    },
    props: {
        table: {
            type: Object,
            required: true,
        },
        searchPlaceholder: {
            type: String,
        },
        isTable: {
            type: Boolean,
            default: true,
        },
    },
    setup({}, {}) {
        //
        return {};
    },
});

const _hoisted_1$l = { class: "inline-flex justify-end w-full pt-4 pr-6 text-gray" };

function render$f(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Search = vue.resolveComponent("Search");
  const _component_Pagination = vue.resolveComponent("Pagination");

  return (vue.openBlock(), vue.createElementBlock("div", null, [
    vue.renderSlot(_ctx.$slots, "search", {}, () => [
      vue.createVNode(_component_Search, {
        table: _ctx.table,
        placeholder: _ctx.searchPlaceholder
      }, null, 8 /* PROPS */, ["table", "placeholder"])
    ]),
    vue.createElementVNode("div", {
      class: vue.normalizeClass(["w-full pt-9", { 'bg-white shadow rounded-md': _ctx.isTable }])
    }, [
      vue.renderSlot(_ctx.$slots, "default"),
      vue.renderSlot(_ctx.$slots, "footer", {}, () => [
        (_ctx.isTable || _ctx.table.totalItems >= _ctx.table.perPage)
          ? (vue.openBlock(), vue.createElementBlock("div", {
              key: 0,
              class: vue.normalizeClass(["w-full pt-8 pb-4", { 'border-t border-gray-300': _ctx.isTable }])
            }, [
              vue.createVNode(_component_Pagination, { table: _ctx.table }, null, 8 /* PROPS */, ["table"]),
              vue.createElementVNode("div", _hoisted_1$l, vue.toDisplayString(_ctx.table.fromItem) + "-" + vue.toDisplayString(_ctx.table.toItem) + "/" + vue.toDisplayString(_ctx.table.totalItems), 1 /* TEXT */)
            ], 2 /* CLASS */))
          : vue.createCommentVNode("v-if", true)
      ])
    ], 2 /* CLASS */),
    vue.renderSlot(_ctx.$slots, "pagination")
  ]))
}

script$o.render = render$f;
script$o.__file = "packages/admin-vue3/src/ui/Index.vue";

const _hoisted_1$k = { class: "px-2 py-1 bg-white draggable-wrapper" };
const _hoisted_2$h = { class: "flex items-center justify-between w-full" };
const _hoisted_3$c = { class: "flex justify-between flex-1 pl-3 pr-2 rounded hover:bg-gray-300" };
const _hoisted_4$9 = /*#__PURE__*/ vue.createElementVNode("div", { class: "flex items-center pr-2 cursor-move text-gray handle" }, [
    /*#__PURE__*/ vue.createElementVNode("svg", {
        xmlns: "http://www.w3.org/2000/svg",
        viewBox: "0 0 24 24",
        class: "w-4 h-4 fill-current",
        fill: "currentColor"
    }, [
        /*#__PURE__*/ vue.createElementVNode("g", null, [
            /*#__PURE__*/ vue.createElementVNode("rect", {
                fill: "none",
                height: "24",
                width: "24"
            })
        ]),
        /*#__PURE__*/ vue.createElementVNode("g", null, [
            /*#__PURE__*/ vue.createElementVNode("g", null, [
                /*#__PURE__*/ vue.createElementVNode("g", null, [
                    /*#__PURE__*/ vue.createElementVNode("path", { d: "M20,9H4v2h16V9z M4,15h16v-2H4V15z" })
                ])
            ])
        ])
    ])
], -1 /* HOISTED */);
const _hoisted_5$6 = { class: "flex items-center justify-between flex-1 py-1" };
const _hoisted_6$2 = { class: "flex items-center w-8" };
const _hoisted_7$2 = /*#__PURE__*/ vue.createElementVNode("svg", {
    width: "24",
    height: "24",
    "stroke-width": "1.5",
    viewBox: "0 0 24 24",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    class: "w-3 h-3"
}, [
    /*#__PURE__*/ vue.createElementVNode("path", {
        d: "M6 9L12 15L18 9",
        stroke: "currentColor",
        "stroke-linecap": "round",
        "stroke-linejoin": "round"
    })
], -1 /* HOISTED */);
var script$n = /*#__PURE__*/ vue.defineComponent({
    props: {
        list: {
            required: true,
            type: Object,
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(vue.unref(Draggable__default), {
                tag: "div",
                list: __props.list.items,
                handle: ".handle",
                "item-key": "uuid"
            }, {
                item: vue.withCtx(({ element }) => [
                    vue.createElementVNode("div", _hoisted_1$k, [
                        vue.createVNode(vue.unref(vue$1.Disclosure), { defaultOpen: "" }, {
                            default: vue.withCtx(({ open }) => [
                                vue.createElementVNode("div", _hoisted_2$h, [
                                    vue.createElementVNode("div", _hoisted_3$c, [
                                        _hoisted_4$9,
                                        vue.createElementVNode("div", _hoisted_5$6, [
                                            vue.renderSlot(_ctx.$slots, "default", { item: element })
                                        ])
                                    ]),
                                    vue.createElementVNode("div", _hoisted_6$2, [
                                        (element.children?.items.length > 0)
                                            ? (vue.openBlock(), vue.createBlock(vue.unref(vue$1.DisclosureButton), {
                                                key: 0,
                                                class: vue.normalizeClass(["p-1 hover:bg-gray-400 rounded-xs", { 'rotate-180': !open }])
                                            }, {
                                                default: vue.withCtx(() => [
                                                    _hoisted_7$2
                                                ]),
                                                _: 2 /* DYNAMIC */
                                            }, 1032 /* PROPS, DYNAMIC_SLOTS */, ["class"]))
                                            : vue.createCommentVNode("v-if", true)
                                    ])
                                ]),
                                vue.createVNode(vue.unref(vue$1.DisclosurePanel), { class: "pl-6" }, {
                                    default: vue.withCtx(() => [
                                        vue.renderSlot(_ctx.$slots, "disclosure", { item: element })
                                    ]),
                                    _: 2 /* DYNAMIC */
                                }, 1024 /* DYNAMIC_SLOTS */)
                            ]),
                            _: 2 /* DYNAMIC */
                        }, 1024 /* DYNAMIC_SLOTS */)
                    ])
                ]),
                _: 3 /* FORWARDED */
            }, 8 /* PROPS */, ["list"]));
        };
    }
});

script$n.__file = "packages/admin-vue3/src/ui/List.vue";

const _withScopeId = n => (vue.pushScopeId("data-v-51936cec"), n = n(), vue.popScopeId(), n);
const _hoisted_1$j = { class: "relative" };
const _hoisted_2$g = { class: "absolute top-0 left-0 right-0 flex w-full h-full max-w-full pointer-events-none" };
const _hoisted_3$b = /*#__PURE__*/ _withScopeId(() => /*#__PURE__*/ vue.createElementVNode("div", { class: "border-l input-section-1 border-t border-b border-gray-900 w-[16px] h-full rounded-l-[8px]" }, null, -1 /* HOISTED */));
const _hoisted_4$8 = ["for"];
const _hoisted_5$5 = /*#__PURE__*/ _withScopeId(() => /*#__PURE__*/ vue.createElementVNode("div", { class: "border-r border-t input-section-3 border-b focus:border-orange border-gray-900 flex-grow rounded-r-[8px] h-full" }, null, -1 /* HOISTED */));
const _hoisted_6$1 = {
    key: 0,
    class: "absolute inline-block -translate-y-1/2 left-5"
};
const _hoisted_7$1 = { class: "absolute inline-block -translate-y-1/2 mcr-select-arrow right-5" };
const _hoisted_8$1 = /*#__PURE__*/ _withScopeId(() => /*#__PURE__*/ vue.createElementVNode("path", { d: "M7.071 5.314l4.95-4.95a1 1 0 1 1 1.414 1.414L7.778 7.435a1 1 0 0 1-1.414 0L.707 1.778A1 1 0 1 1 2.121.364l4.95 4.95z" }, null, -1 /* HOISTED */));
const _hoisted_9$1 = [
    _hoisted_8$1
];
var script$m = /*#__PURE__*/ vue.defineComponent({
    props: {
        modelValue: {},
        options: {
            type: Array,
            required: true,
        },
        label: {
            type: String,
            default: null,
        },
        labelKey: {
            type: String,
            default: null,
        },
        valueKey: {
            type: String,
            default: null,
        },
        errors: {
            type: [Array, String],
            default: null,
        },
        placeholder: {
            type: String,
            default: 'Wählen Sie eine Option',
        },
        disabled: {
            type: Boolean,
            default: false,
        },
    },
    emits: ['update:modelValue', 'change'],
    setup(__props, { emit }) {
        const props = __props;
        const getItemValue = (item) => {
            if (props.valueKey) {
                return item[props.valueKey];
            }
            return item;
        };
        const getItemLabel = (item) => {
            if (props.labelKey) {
                return item[props.labelKey];
            }
            return item;
        };
        const itemLabel = vue.computed(() => {
            if (!props.modelValue) {
                return props.placeholder;
            }
            if (props.valueKey) {
                let selectedOption = props.options.find((option) => option[props.valueKey] == props.modelValue);
                return selectedOption[props.labelKey];
            }
            return props.modelValue;
        });
        const selectedItem = vue.ref(props.modelValue);
        vue.watch(selectedItem, () => {
            emit('update:modelValue', selectedItem.value);
            emit('change');
        });
        return (_ctx, _cache) => {
            return (vue.unref(itemLabel))
                ? (vue.openBlock(), vue.createBlock(vue.unref(vue$1.Listbox), {
                    key: 0,
                    disabled: __props.disabled,
                    modelValue: selectedItem.value,
                    "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => ((selectedItem).value = $event))
                }, {
                    default: vue.withCtx(({ open }) => [
                        vue.createElementVNode("div", _hoisted_1$j, [
                            vue.createVNode(vue.unref(vue$1.ListboxButton), {
                                class: vue.normalizeClass(["px-[18px] mcr-select-button z-10 w-full transition-colors duration-200 bg-transparent focus:outline-none focus:input-focused text-indigo-900 py-[22px]", {
                                        'cursor-not-allowed': __props.disabled,
                                        'has-errors': __props.errors?.length > 0 && !__props.disabled,
                                    }])
                            }, {
                                default: vue.withCtx(() => [
                                    vue.createElementVNode("div", _hoisted_2$g, [
                                        _hoisted_3$b,
                                        vue.createElementVNode("div", {
                                            class: vue.normalizeClass(["relative h-full px-1 border-t border-b border-gray-900 input-width input-section-2", {
                                                    '!border-t-transparent': selectedItem.value || _ctx.focused,
                                                    'border-t-gray-900': !selectedItem.value,
                                                }])
                                        }, [
                                            vue.createElementVNode("label", {
                                                class: vue.normalizeClass(["relative inline-block text-sm transition duration-200 origin-left whitespace-nowrap will-change-auto h-fit top-1/2", {
                                                        'text-ellipsis !-translate-y-[35px] !scale-100 text-indigo-900': selectedItem.value || _ctx.focused,
                                                        'max-w-full -translate-y-[13px] scale-[1.34] text-gray-500': !selectedItem.value,
                                                        '!text-red-signal': (selectedItem.value &&
                                                            __props.errors?.length > 0 &&
                                                            !__props.disabled) ||
                                                            (_ctx.focused &&
                                                                __props.errors?.length > 0 &&
                                                                !__props.disabled),
                                                    }]),
                                                ref: (_value, _refs) => {
                                                    _refs['inputLabel'] = _value;
                                                },
                                                for: _ctx.id
                                            }, vue.toDisplayString(__props.label), 11 /* TEXT, CLASS, PROPS */, _hoisted_4$8)
                                        ], 2 /* CLASS */),
                                        _hoisted_5$5
                                    ]),
                                    (selectedItem.value)
                                        ? (vue.openBlock(), vue.createElementBlock("span", _hoisted_6$1, vue.toDisplayString(vue.unref(itemLabel)), 1 /* TEXT */))
                                        : vue.createCommentVNode("v-if", true),
                                    vue.createElementVNode("span", _hoisted_7$1, [
                                        (vue.openBlock(), vue.createElementBlock("svg", {
                                            class: vue.normalizeClass(["transition-transform duration-200", { 'rotate-180': open }]),
                                            xmlns: "http://www.w3.org/2000/svg",
                                            viewBox: "-5 -8 24 24",
                                            width: "16",
                                            fill: "currentColor"
                                        }, _hoisted_9$1, 2 /* CLASS */))
                                    ])
                                ]),
                                _: 2 /* DYNAMIC */
                            }, 1032 /* PROPS, DYNAMIC_SLOTS */, ["class"]),
                            vue.createVNode(vue.Transition, {
                                "leave-active-class": "transition duration-200 ease-in",
                                "leave-from-class": "opacity-100",
                                "leave-to-class": "opacity-0"
                            }, {
                                default: vue.withCtx(() => [
                                    vue.createVNode(vue.unref(vue$1.ListboxOptions), { class: "absolute z-40 w-full mt-2 py-2.5 overflow-auto rounded-[8px] bg-white shadow max-h-48 focus:outline-none" }, {
                                        default: vue.withCtx(() => [
                                            (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(__props.options, (item) => {
                                                return (vue.openBlock(), vue.createBlock(vue.unref(vue$1.ListboxOption), {
                                                    value: getItemValue(item),
                                                    as: "template"
                                                }, {
                                                    default: vue.withCtx(({ active, selected }) => [
                                                        vue.createElementVNode("li", {
                                                            class: vue.normalizeClass([
                                                                selected ? 'bg-gray-100' : 'hover:bg-gray-100',
                                                                active ? 'bg-gray-100' : 'hover:bg-gray-100',
                                                                'cursor-pointer select-none relative',
                                                            ])
                                                        }, [
                                                            vue.createElementVNode("span", {
                                                                class: vue.normalizeClass([
                                                                    selected ? 'text-indigo-900' : 'text-gray',
                                                                    'block truncate py-[5px] px-4',
                                                                ])
                                                            }, vue.toDisplayString(getItemLabel(item)), 3 /* TEXT, CLASS */)
                                                        ], 2 /* CLASS */)
                                                    ]),
                                                    _: 2 /* DYNAMIC */
                                                }, 1032 /* PROPS, DYNAMIC_SLOTS */, ["value"]));
                                            }), 256 /* UNKEYED_FRAGMENT */))
                                        ]),
                                        _: 1 /* STABLE */
                                    })
                                ]),
                                _: 1 /* STABLE */
                            })
                        ])
                    ]),
                    _: 1 /* STABLE */
                }, 8 /* PROPS */, ["disabled", "modelValue"]))
                : vue.createCommentVNode("v-if", true);
        };
    }
});

var css$2 = "\n.mcr-select-button:focus > div > .input-section-1[data-v-51936cec] {\n    border-color: #fead5e;\n}\n.mcr-select-button:focus > div > .input-section-2[data-v-51936cec] {\n    border-bottom-color: #fead5e;\n    border-top-color: #fead5e;\n}\n.mcr-select-button:focus > div > .input-section-2 > label[data-v-51936cec] {\n    color: #fead5e;\n}\n.mcr-select-button:focus > div > .input-section-3[data-v-51936cec] {\n    border-color: #fead5e;\n}\n.mcr-select-button:focus .mcr-select-arrow[data-v-51936cec] {\n    color: #fead5e;\n}\n.input-width[data-v-51936cec] {\n    flex: 0 0 auto;\n    max-width: calc(100% - 12px * 2);\n}\n.input-width-focused[data-v-51936cec] {\n    max-width: calc(100% * 0.75);\n}\n.mcr-select-button.has-errors .mcr-select-arrow[data-v-51936cec] {\n    color: #f74b6d;\n}\n.mcr-select-button.has-errors > div > .input-section-1[data-v-51936cec] {\n    border-color: #f74b6d;\n}\n.mcr-select-button.has-errors > div > .input-section-2[data-v-51936cec] {\n    border-bottom-color: #f74b6d;\n    border-top-color: #f74b6d;\n    color: #f74b6d;\n}\n.mcr-select-button.has-errors > div > .input-section-3[data-v-51936cec] {\n    border-color: #f74b6d;\n}\n";
n(css$2,{});

script$m.__scopeId = "data-v-51936cec";
script$m.__file = "packages/admin-vue3/src/ui/Select.vue";

const _hoisted_1$i = {
    key: 0,
    class: "absolute top-0 flex items-center justify-center w-full h-full text-gray"
};
const _hoisted_2$f = /*#__PURE__*/ vue.createTextVNode(" Drag your content here ");
var script$l = /*#__PURE__*/ vue.defineComponent({
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", {
                class: vue.normalizeClass(["min-h-[20px] space-y-2 rounded relative", {
                        'outline-dashed outline-3 outline-gray h-36': Object.keys(_ctx.$attrs.modelValue).length == 0,
                    }])
            }, [
                (Object.keys(_ctx.$attrs.modelValue).length == 0)
                    ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$i, [
                        vue.renderSlot(_ctx.$slots, "drag-text", {}, () => [
                            _hoisted_2$f
                        ])
                    ]))
                    : vue.createCommentVNode("v-if", true),
                vue.createVNode(vue.unref(pageBuilderVue3.Sections), vue.normalizeProps(vue.guardReactiveProps(_ctx.$attrs)), null, 16 /* FULL_PROPS */)
            ], 2 /* CLASS */));
        };
    }
});

script$l.__file = "packages/admin-vue3/src/ui/Sections.vue";

var script$k = vue.defineComponent({
    components: {
        TransitionRoot: vue$1.TransitionRoot,
        TransitionChild: vue$1.TransitionChild,
        Dialog: vue$1.Dialog,
        DialogOverlay: vue$1.DialogOverlay,
        DialogTitle: vue$1.DialogTitle,
    },
    props: {
        open: {
            type: Boolean,
            required: true,
        },
    },
});

const _hoisted_1$h = { class: "fixed top-0 right-0 z-10 w-64 h-full mt-6 bg-white border-l border-gray-300 shadow pt-14" };
const _hoisted_2$e = { class: "min-h-screen text-center" };
const _hoisted_3$a = { class: "inline-block w-full max-w-md overflow-y-scroll text-left transition-all transform" };
const _hoisted_4$7 = /*#__PURE__*/vue.createElementVNode("svg", {
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24",
  width: "24",
  height: "24"
}, [
  /*#__PURE__*/vue.createElementVNode("path", {
    fill: "none",
    d: "M0 0h24v24H0z"
  }),
  /*#__PURE__*/vue.createElementVNode("path", { d: "M7.828 11H20v2H7.828l5.364 5.364-1.414 1.414L4 12l7.778-7.778 1.414 1.414z" })
], -1 /* HOISTED */);
const _hoisted_5$4 = [
  _hoisted_4$7
];

function render$e(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_DialogOverlay = vue.resolveComponent("DialogOverlay");
  const _component_TransitionChild = vue.resolveComponent("TransitionChild");
  const _component_Dialog = vue.resolveComponent("Dialog");
  const _component_TransitionRoot = vue.resolveComponent("TransitionRoot");

  return (vue.openBlock(), vue.createBlock(_component_TransitionRoot, {
    show: _ctx.open,
    as: "template",
    enter: "transition-all duration-75",
    "enter-to": "opacity-100",
    leave: "transition-all duration-150",
    "enter-from": "transform translate-x-full",
    "leave-from": "transformtranslate-x-full",
    "leave-to": "transform translate-x-full"
  }, {
    default: vue.withCtx(() => [
      vue.createVNode(_component_Dialog, vue.mergeProps({ as: "div" }, _ctx.$attrs, { open: _ctx.open }), {
        default: vue.withCtx(() => [
          vue.createElementVNode("div", _hoisted_1$h, [
            vue.createElementVNode("aside", _hoisted_2$e, [
              vue.createVNode(_component_TransitionChild, {
                as: "template",
                enter: "duration-300 ease-out",
                "enter-from": "opacity-0",
                "enter-to": "opacity-100",
                leave: "duration-200 ease-in",
                "leave-from": "opacity-100",
                "leave-to": "opacity-0"
              }, {
                default: vue.withCtx(() => [
                  vue.createVNode(_component_DialogOverlay, { class: "fixed inset-0" })
                ]),
                _: 1 /* STABLE */
              }),
              vue.createVNode(_component_TransitionChild, {
                as: "template",
                enter: "duration-300 ease-out",
                "enter-from": "opacity-0 scale-95",
                "enter-to": "opacity-100 scale-100",
                leave: "duration-200 ease-in",
                "leave-from": "opacity-100 scale-100",
                "leave-to": "opacity-0 scale-95"
              }, {
                default: vue.withCtx(() => [
                  vue.createElementVNode("div", _hoisted_3$a, [
                    vue.createElementVNode("button", {
                      onClick: _cache[0] || (_cache[0] = $event => (_ctx.$emit('close', false)))
                    }, _hoisted_5$4),
                    vue.renderSlot(_ctx.$slots, "default")
                  ])
                ]),
                _: 3 /* FORWARDED */
              })
            ])
          ])
        ]),
        _: 3 /* FORWARDED */
      }, 16 /* FULL_PROPS */, ["open"])
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["show"]))
}

script$k.render = render$e;
script$k.__file = "packages/admin-vue3/src/ui/Sidebar.vue";

var script$j = /*#__PURE__*/ vue.defineComponent({
    props: {
        title: {
            type: String,
        },
        href: {
            type: String,
        },
        expanded: {
            type: Boolean,
            default: false,
        },
    },
    setup(__props) {
        const page = vue.computed(() => {
            return inertiaVue3.usePage().url.value;
        });
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(vue.unref(inertiaVue3.Link), {
                href: __props.href,
                class: vue.normalizeClass([{
                        'bg-orange bg-opacity-20 hover:bg-opacity-50': vue.unref(page).includes(__props.href),
                        'hover:bg-gray-300': !vue.unref(page).includes(__props.href),
                    }, "flex items-center rounded"])
            }, {
                default: vue.withCtx(() => [
                    vue.createElementVNode("div", {
                        class: vue.normalizeClass(["w-[44px] min-w-[44px] h-[44px] rounded flex items-center text-gray-800 justify-center", {
                                ' text-red': vue.unref(page).includes(__props.href),
                            }])
                    }, [
                        vue.renderSlot(_ctx.$slots, "default")
                    ], 2 /* CLASS */),
                    (__props.expanded)
                        ? (vue.openBlock(), vue.createElementBlock("div", {
                            key: 0,
                            class: vue.normalizeClass(["flex-1 pl-3 font-medium tracking-wider", {
                                    'text-red': vue.unref(page).includes(__props.href),
                                }])
                        }, vue.toDisplayString(__props.title), 3 /* TEXT, CLASS */))
                        : vue.createCommentVNode("v-if", true)
                ]),
                _: 3 /* FORWARDED */
            }, 8 /* PROPS */, ["href", "class"]));
        };
    }
});

script$j.__file = "packages/admin-vue3/src/ui/SidebarLink.vue";

const _hoisted_1$g = { class: "p-4 space-y-2" };
const _hoisted_2$d = { class: "inline-block" };
const _hoisted_3$9 = /*#__PURE__*/ vue.createElementVNode("path", { d: "M7.071 5.314l4.95-4.95a1 1 0 1 1 1.414 1.414L7.778 7.435a1 1 0 0 1-1.414 0L.707 1.778A1 1 0 1 1 2.121.364l4.95 4.95z" }, null, -1 /* HOISTED */);
const _hoisted_4$6 = [
    _hoisted_3$9
];
var script$i = /*#__PURE__*/ vue.defineComponent({
    props: {
        title: {
            type: String,
        },
        expanded: {
            type: Boolean,
            default: false,
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(vue.unref(vue$1.Disclosure), { defaultOpen: "" }, {
                default: vue.withCtx(() => [
                    vue.createElementVNode("section", _hoisted_1$g, [
                        vue.createVNode(vue.unref(vue$1.DisclosureButton), {
                            class: vue.normalizeClass(["flex items-center justify-between w-full mb-3 text-sm tracking-widest uppercase transition-opacity text-gray", {
                                    'opacity-100': __props.expanded,
                                    'opacity-0': !__props.expanded,
                                }])
                        }, {
                            default: vue.withCtx(({ open }) => [
                                vue.createElementVNode("span", _hoisted_2$d, vue.toDisplayString(__props.title), 1 /* TEXT */),
                                (vue.openBlock(), vue.createElementBlock("svg", {
                                    xmlns: "http://www.w3.org/2000/svg",
                                    viewBox: "-5 -8 24 24",
                                    width: "24",
                                    class: vue.normalizeClass(["w-3 h-3 fill-gray-800", { 'rotate-180': !open }])
                                }, _hoisted_4$6, 2 /* CLASS */))
                            ]),
                            _: 1 /* STABLE */
                        }, 8 /* PROPS */, ["class"]),
                        vue.createVNode(vue.unref(vue$1.DisclosurePanel), { class: "flex flex-col space-y-2" }, {
                            default: vue.withCtx(() => [
                                vue.renderSlot(_ctx.$slots, "default")
                            ]),
                            _: 3 /* FORWARDED */
                        })
                    ])
                ]),
                _: 3 /* FORWARDED */
            }));
        };
    }
});

script$i.__file = "packages/admin-vue3/src/ui/SidebarSection.vue";

const _hoisted_1$f = { class: "flex items-center justify-between h-20 px-4 py-7" };
const _hoisted_2$c = { class: "relative flex items-center w-full h-10 overflow-hidden" };
const _hoisted_3$8 = { class: "w-36" };
const _hoisted_4$5 = { class: "flex-1" };
const _hoisted_5$3 = { class: "flex px-5 py-6" };
const _hoisted_6 = /*#__PURE__*/ vue.createElementVNode("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "-2.5 -2.5 24 24",
    class: "w-4 h-4 fill-current"
}, [
    /*#__PURE__*/ vue.createElementVNode("path", { d: "M8 14A6 6 0 1 0 8 2a6 6 0 0 0 0 12zm6.32-1.094l3.58 3.58a1 1 0 1 1-1.415 1.413l-3.58-3.58a8 8 0 1 1 1.414-1.414z" })
], -1 /* HOISTED */);
const _hoisted_7 = [
    _hoisted_6
];
const _hoisted_8 = { class: "flex items-center h-56 gap-3 overflow-y-auto" };
const _hoisted_9 = /*#__PURE__*/ vue.createElementVNode("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "-2.5 -2.5 24 24",
    width: "16",
    height: "16",
    preserveAspectRatio: "xMinYMin",
    class: "fill-gray-800 icon__icon"
}, [
    /*#__PURE__*/ vue.createElementVNode("path", { d: "M8 14A6 6 0 1 0 8 2a6 6 0 0 0 0 12zm6.32-1.094l3.58 3.58a1 1 0 1 1-1.415 1.413l-3.58-3.58a8 8 0 1 1 1.414-1.414z" })
], -1 /* HOISTED */);
var script$h = /*#__PURE__*/ vue.defineComponent({
    props: {
        sidebar: Object,
    },
    setup(__props) {
        const globalSearchOpen = vue.ref(false);
        const globalSearchTerm = vue.ref('');
        vue.computed(() => {
            return inertiaVue3.usePage().url.value;
        });
        const expanded = vue.ref(false);
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", {
                class: vue.normalizeClass(["flex flex-col justify-between h-screen transition-all bg-white border-r border-gray-400", {
                        'w-[77px]': !expanded.value,
                        'w-[250px]': expanded.value,
                    }]),
                onMouseover: _cache[3] || (_cache[3] = ($event) => (expanded.value = true)),
                onMouseleave: _cache[4] || (_cache[4] = ($event) => (expanded.value = false))
            }, [
                vue.createElementVNode("header", _hoisted_1$f, [
                    vue.createElementVNode("div", _hoisted_2$c, [
                        vue.createVNode(vue.unref(inertiaVue3.Link), { href: "/admin" }, {
                            default: vue.withCtx(() => [
                                vue.createElementVNode("div", _hoisted_3$8, [
                                    vue.renderSlot(_ctx.$slots, "logo")
                                ])
                            ]),
                            _: 3 /* FORWARDED */
                        })
                    ])
                ]),
                vue.createElementVNode("nav", _hoisted_4$5, [
                    vue.renderSlot(_ctx.$slots, "default", { expanded: expanded.value })
                ]),
                vue.createElementVNode("footer", _hoisted_5$3, [
                    vue.createElementVNode("button", {
                        onClick: _cache[0] || (_cache[0] = ($event) => (globalSearchOpen.value = true)),
                        class: "flex items-center justify-center bg-gray-300 rounded w-9 h-9"
                    }, _hoisted_7),
                    vue.createVNode(script$y, {
                        lg: "",
                        open: globalSearchOpen.value,
                        "onUpdate:open": _cache[2] || (_cache[2] = ($event) => ((globalSearchOpen).value = $event))
                    }, {
                        default: vue.withCtx(() => [
                            vue.createElementVNode("div", _hoisted_8, [
                                _hoisted_9,
                                vue.createVNode(vue.unref(macrameVue3.Input), {
                                    class: "flex-1",
                                    modelValue: globalSearchTerm.value,
                                    "onUpdate:modelValue": _cache[1] || (_cache[1] = ($event) => ((globalSearchTerm).value = $event)),
                                    modelModifiers: { debounce: true }
                                }, null, 8 /* PROPS */, ["modelValue"])
                            ])
                        ]),
                        _: 1 /* STABLE */
                    }, 8 /* PROPS */, ["open"])
                ])
            ], 34 /* CLASS, HYDRATE_EVENTS */));
        };
    }
});

script$h.__file = "packages/admin-vue3/src/ui/SidebarPrimary.vue";

const _hoisted_1$e = { class: "flex flex-col justify-between h-screen bg-white w-[320px] border-r border-gray-400" };
const _hoisted_2$b = { class: "flex items-center justify-between h-20 px-5 border-b border-gray-400" };
const _hoisted_3$7 = { class: "flex-1 max-h-[calc(100vh - 80px)] overflow-y-auto" };

function render$d(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$e, [
    vue.createElementVNode("header", _hoisted_2$b, [
      vue.renderSlot(_ctx.$slots, "header")
    ]),
    vue.createElementVNode("nav", _hoisted_3$7, [
      vue.renderSlot(_ctx.$slots, "default")
    ])
  ]))
}

const script$g = {};


script$g.render = render$d;
script$g.__file = "packages/admin-vue3/src/ui/SidebarSecondary.vue";

const _hoisted_1$d = { key: 0 };
const _hoisted_2$a = { key: 1 };
var script$f = /*#__PURE__*/ vue.defineComponent({
    props: {
        table: {
            type: Object,
            required: false,
        },
        sortBy: {
            type: String,
            required: false,
        },
    },
    setup(__props) {
        const props = __props;
        const isSortable = vue.computed(() => !!props.sortBy && !!props.table);
        const applySort = () => {
            if (!isSortable) {
                return;
            }
            if (!props.table.isSortedBy(props.sortBy)) {
                console.log('Add new (asc)');
                props.table.addSortBy(props.sortBy);
            }
            else if (props.table.isSortedBy(props.sortBy, 'asc')) {
                console.log('Change new (desc)');
                props.table.addSortBy(props.sortBy, 'desc');
            }
            else {
                console.log('Remove');
                props.table.removeSortBy(props.sortBy);
            }
        };
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("th", {
                class: vue.normalizeClass(["pb-2 pl-6 font-light bg-white border-b text-gray border-gray slim", {
                        'cursor-pointer': vue.unref(isSortable),
                    }]),
                onClick: _cache[0] || (_cache[0] = ($event) => (applySort()))
            }, [
                vue.renderSlot(_ctx.$slots, "default"),
                (vue.unref(isSortable))
                    ? (vue.openBlock(), vue.createElementBlock(vue.Fragment, { key: 0 }, [
                        (__props.table.isSortedBy(__props.sortBy, 'desc'))
                            ? (vue.openBlock(), vue.createElementBlock("span", _hoisted_1$d, " DESC "))
                            : vue.createCommentVNode("v-if", true),
                        (__props.table.isSortedBy(__props.sortBy, 'asc'))
                            ? (vue.openBlock(), vue.createElementBlock("span", _hoisted_2$a, " ASC "))
                            : vue.createCommentVNode("v-if", true)
                    ], 64 /* STABLE_FRAGMENT */))
                    : vue.createCommentVNode("v-if", true)
            ], 2 /* CLASS */));
        };
    }
});

script$f.__file = "packages/admin-vue3/src/ui/Th.vue";

var script$e = vue.defineComponent({
    props: {
        slim: {
            type: Boolean,
            default: false,
        },
    },
});

function render$c(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createElementBlock("td", {
    class: vue.normalizeClass(["py-5 pl-6 pr-6", { slim: _ctx.slim }])
  }, [
    vue.renderSlot(_ctx.$slots, "default")
  ], 2 /* CLASS */))
}

script$e.render = render$c;
script$e.__file = "packages/admin-vue3/src/ui/Td.vue";

var script$d = vue.defineComponent({
    components: { Th: script$f, Td: script$e },
    props: {
        selectable: {
            type: Boolean,
            default: false,
        },
        table: {
            type: Object,
            required: true,
        },
        schema: {
            type: Array,
            required: false,
        },
    },
});

const _hoisted_1$c = { class: "table w-full" };
const _hoisted_2$9 = { class: "sticky top-0 text-left text-gray-800 bg-white thead" };

function render$b(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Th = vue.resolveComponent("Th");
  const _component_Td = vue.resolveComponent("Td");
  const _component_Tr = vue.resolveComponent("Tr");

  return (vue.openBlock(), vue.createElementBlock("table", _hoisted_1$c, [
    vue.createElementVNode("thead", _hoisted_2$9, [
      vue.renderSlot(_ctx.$slots, "thead", {}, () => [
        vue.createElementVNode("tr", null, [
          (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(_ctx.schema, (column, thKey) => {
            return (vue.openBlock(), vue.createBlock(_component_Th, {
              key: `th-${thKey}`,
              column: column,
              class: "pr-4 text-xs font-normal bg-white h-7"
            }, null, 8 /* PROPS */, ["column"]))
          }), 128 /* KEYED_FRAGMENT */))
        ])
      ])
    ]),
    vue.createElementVNode("tbody", null, [
      vue.renderSlot(_ctx.$slots, "tbody", {
        items: _ctx.table.items
      }, () => [
        (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(_ctx.table.items, (item, trKey) => {
          return (vue.openBlock(), vue.createBlock(_component_Tr, {
            key: `th-${trKey}`
          }, {
            default: vue.withCtx(() => [
              (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(_ctx.schema, (column, tdKey) => {
                return (vue.openBlock(), vue.createBlock(_component_Td, {
                  key: `td-${tdKey}`,
                  column: column,
                  item: item,
                  class: "py-4 pr-4"
                }, null, 8 /* PROPS */, ["column", "item"]))
              }), 128 /* KEYED_FRAGMENT */))
            ]),
            _: 2 /* DYNAMIC */
          }, 1024 /* DYNAMIC_SLOTS */))
        }), 128 /* KEYED_FRAGMENT */))
      ])
    ])
  ]))
}

var css$1 = "\n.table .slim {\n    width: 1%;\n    white-space: nowrap;\n}\n.table .thead {\n    box-shadow: inset 0px -1px 0px #e5eaef;\n}\n";
n(css$1,{});

script$d.render = render$b;
script$d.__file = "packages/admin-vue3/src/ui/Table.vue";

const _hoisted_1$b = ["value"];
var script$c = /*#__PURE__*/ vue.defineComponent({
    props: {
        modelValue: String,
        errors: {
            type: Array,
            default: [],
        },
        hint: {
            type: String,
            default: null,
        },
    },
    emits: ['update:modelValue'],
    setup(__props, { emit: emits }) {
        const updateValue = event => {
            emits('update:modelValue', event.target.value);
        };
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("textarea", vue.mergeProps(_ctx.$attrs, {
                class: ["bg-white border w-full transition-colors duration-300 focus:outline-none placeholder:text-gray-900 h-[118px] overflow-y-scroll overflow-x-hidden rounded-[8px] px-[18px] py-3", {
                        'border-red-signal': __props.errors.length > 0,
                        'border-gray-900 focus:border-orange': __props.errors.length == 0,
                    }],
                value: __props.modelValue,
                onInput: updateValue
            }), null, 16 /* FULL_PROPS */, _hoisted_1$b));
        };
    }
});

script$c.__file = "packages/admin-vue3/src/ui/Textarea.vue";

var script$b = vue.defineComponent({
//
});

const _hoisted_1$a = { class: "hover:bg-gray-200 odd:bg-gray-50" };

function render$a(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createElementBlock("tr", _hoisted_1$a, [
    vue.renderSlot(_ctx.$slots, "default")
  ]))
}

script$b.render = render$a;
script$b.__file = "packages/admin-vue3/src/ui/Tr.vue";

var script$a = vue.defineComponent({
    name: 'TransitionSlide',
    props: {
        to: {
            type: String,
            default: 'left',
        },
    },
    setup() {
        //
    },
});

function render$9(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createBlock(vue.Transition, {
    name: `slide-${_ctx.to}`
  }, {
    default: vue.withCtx(() => [
      vue.renderSlot(_ctx.$slots, "default")
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["name"]))
}

var css = "\n.slide-up-enter-active,\n.slide-down-enter-active,\n.slide-left-enter-active,\n.slide-right-enter-active {\n    transition: all 0.1s ease;\n}\n.slide-up-leave-active,\n.slide-down-leave-active,\n.slide-left-leave-active,\n.slide-right-leave-active {\n    transition: all 0.1s ease;\n}\n.slide-up-enter-from,\n.slide-up-leave-to {\n    transform: translateY(100%);\n}\n.slide-down-enter-from,\n.slide-down-leave-to {\n    transform: translateY(-100%);\n}\n.slide-left-enter-from,\n.slide-left-leave-to {\n    transform: translateX(100%);\n}\n.slide-right-enter-from,\n.slide-right-leave-to {\n    transform: translateX(-100%);\n}\n";
n(css,{});

script$a.render = render$9;
script$a.__file = "packages/admin-vue3/src/transitions/TransitionSlide.vue";

var script$9 = vue.defineComponent({
    setup() { },
});

const _hoisted_1$9 = {
  width: "100",
  viewBox: "0 0 889 263",
  xmlns: "http://www.w3.org/2000/svg",
  "xml:space": "preserve",
  "fill-rule": "evenodd",
  "clip-rule": "evenodd",
  "stroke-linejoin": "round",
  "stroke-miterlimit": "2"
};
const _hoisted_2$8 = /*#__PURE__*/vue.createStaticVNode("<g transform=\"translate(-204.96 -204.96)\"><path d=\"M204.96 368.93c0 22.64 18.35 40.99 40.99 40.99s40.99-18.35 40.99-40.99V245.95h-81.98v122.98Z\" fill=\"#4951f2\" fill-rule=\"nonzero\"></path><path d=\"M204.96 327.94c0 22.64 18.35 40.99 40.99 40.99s40.99-18.35 40.99-40.99v-81.98h-81.98v81.98Z\" fill=\"#40ffa4\" fill-opacity=\".42\" fill-rule=\"nonzero\"></path><path d=\"M204.96 286.94c0 22.64 18.35 40.99 40.99 40.99s40.99-18.35 40.99-40.99v-40.99h-81.98v40.99Z\" fill=\"#40ffa4\" fill-opacity=\".42\" fill-rule=\"nonzero\"></path><circle cx=\"245.95\" cy=\"245.95\" r=\"40.99\" fill=\"#40ffa4\"></circle><circle cx=\"332.48\" cy=\"426.66\" r=\"40.99\" fill=\"#4951f2\"></circle><path fill=\"#fff\" d=\"M459.11 237.6h23.11v130.76h-23.11zM507.77 270.29h23.11v98.07h-23.11z\"></path><path d=\"M519.39 231.28c-3.66 0-6.81 1.22-9.45 3.67-2.64 2.45-3.96 5.42-3.96 8.91 0 3.45 1.31 6.4 3.93 8.84 2.62 2.45 5.78 3.67 9.48 3.67 3.66 0 6.8-1.22 9.42-3.67s3.93-5.39 3.93-8.84c0-3.49-1.31-6.46-3.93-8.91s-5.76-3.67-9.42-3.67ZM600.52 349.91c-1.21.22-2.54.32-3.99.32-1.92 0-3.66-.3-5.24-.89-1.57-.59-2.84-1.71-3.8-3.35-.96-1.64-1.44-4.01-1.44-7.12v-50.7h19.35v-17.88h-19.35v-23.5h-23.11v23.5h-13.92v17.88h13.92v54.53c-.04 6.13 1.29 11.24 3.99 15.32 2.7 4.09 6.37 7.1 11.01 9.03 4.64 1.94 9.85 2.82 15.64 2.65 3.28-.08 6.05-.38 8.33-.89 2.28-.51 4.03-.98 5.27-1.4l-3.89-18.07c-.63.16-1.56.35-2.77.57ZM677.12 312.43l-16.73-3.58c-4.98-1.15-8.54-2.62-10.69-4.41-2.15-1.79-3.2-4.11-3.16-6.96-.04-3.32 1.56-6.02 4.82-8.11 3.26-2.09 7.29-3.13 12.1-3.13 3.58 0 6.6.57 9.07 1.72 2.47 1.15 4.44 2.66 5.91 4.53 1.47 1.87 2.5 3.87 3.1 6l21.07-2.3c-1.58-8.34-5.68-14.96-12.29-19.86-6.62-4.89-15.68-7.34-27.17-7.34-7.83 0-14.74 1.22-20.72 3.67-5.98 2.45-10.64 5.9-13.98 10.34-3.34 4.45-4.99 9.7-4.95 15.74-.04 7.15 2.19 13.06 6.7 17.72 4.51 4.66 11.47 7.97 20.88 9.93l16.73 3.51c4.51.98 7.84 2.38 9.99 4.21 2.15 1.83 3.22 4.15 3.22 6.96 0 3.32-1.67 6.11-5.01 8.37-3.34 2.25-7.75 3.38-13.25 3.38-5.32 0-9.64-1.13-12.96-3.38-3.32-2.26-5.49-5.6-6.51-10.03l-22.54 2.17c1.4 9.03 5.77 16.06 13.09 21.1 7.32 5.04 16.99 7.56 28.99 7.56 8.17 0 15.41-1.32 21.7-3.96 6.3-2.64 11.23-6.31 14.78-11.02 3.55-4.7 5.35-10.14 5.4-16.31-.05-7.02-2.33-12.7-6.86-17.05-4.55-4.3-11.45-7.47-20.73-9.47ZM767.87 349.91c-1.21.22-2.54.32-3.99.32-1.91 0-3.66-.3-5.24-.89-1.57-.59-2.84-1.71-3.8-3.35-.96-1.64-1.44-4.01-1.44-7.12v-50.7h19.35v-17.88H753.4v-23.5h-23.1v23.5h-13.92v17.88h13.92v54.53c-.04 6.13 1.29 11.24 3.99 15.32 2.7 4.09 6.37 7.1 11.01 9.03 4.64 1.94 9.86 2.82 15.64 2.65 3.28-.08 6.05-.38 8.33-.89 2.28-.51 4.03-.98 5.27-1.4l-3.89-18.07c-.64.16-1.56.35-2.78.57ZM861.01 276.13c-3.87-2.53-8.15-4.35-12.83-5.46a60.982 60.982 0 0 0-14.11-1.66c-6.86 0-13.11 1.01-18.77 3.03-5.66 2.02-10.45 5.05-14.37 9.07-3.92 4.02-6.73 9.01-8.43 14.97l21.58 3.06c1.15-3.36 3.37-6.28 6.67-8.75 3.3-2.47 7.78-3.7 13.44-3.7 5.36 0 9.47 1.32 12.32 3.96 2.85 2.64 4.28 6.36 4.28 11.17v.38c0 2.21-.82 3.84-2.46 4.88-1.64 1.04-4.25 1.81-7.82 2.3-3.58.49-8.24 1.03-13.98 1.63-4.77.51-9.37 1.33-13.82 2.46-4.45 1.13-8.44 2.78-11.97 4.95-3.53 2.17-6.32 5.07-8.37 8.69-2.04 3.62-3.06 8.19-3.06 13.73 0 6.43 1.44 11.83 4.31 16.22 2.87 4.39 6.79 7.69 11.75 9.93 4.96 2.24 10.55 3.35 16.76 3.35 5.11 0 9.56-.71 13.38-2.14 3.81-1.43 6.98-3.32 9.51-5.68 2.53-2.36 4.5-4.9 5.91-7.63h.76v13.47h22.22v-65.64c0-6.51-1.18-11.94-3.54-16.28-2.37-4.34-5.49-7.78-9.36-10.31Zm-10.16 57.05c0 3.62-.93 6.96-2.78 10.03-1.85 3.06-4.48 5.52-7.88 7.37-3.41 1.85-7.43 2.78-12.07 2.78-4.81 0-8.77-1.08-11.88-3.26-3.11-2.18-4.66-5.38-4.66-9.64 0-2.98.78-5.42 2.36-7.31 1.57-1.89 3.72-3.37 6.45-4.44 2.72-1.06 5.81-1.83 9.26-2.3 1.53-.21 3.34-.47 5.43-.77 2.09-.3 4.19-.64 6.32-1.02s4.06-.83 5.78-1.34c1.72-.51 2.95-1.06 3.67-1.66v11.56ZM929.52 291.45c3.58-2.53 7.73-3.8 12.45-3.8 5.57 0 10.03 1.59 13.38 4.76 3.34 3.17 5.46 7.12 6.35 11.84h22.09c-.51-7.07-2.6-13.25-6.26-18.55-3.66-5.3-8.57-9.41-14.71-12.32-6.15-2.91-13.21-4.37-21.17-4.37-9.58 0-17.87 2.14-24.87 6.42-7 4.28-12.42 10.24-16.25 17.88-3.83 7.64-5.75 16.44-5.75 26.4 0 9.92 1.89 18.68 5.65 26.28 3.77 7.6 9.15 13.55 16.15 17.84 7 4.3 15.4 6.45 25.19 6.45 8.22 0 15.37-1.5 21.45-4.5 6.09-3 10.9-7.17 14.43-12.51 3.53-5.34 5.58-11.48 6.13-18.42H961.7c-.68 3.53-1.94 6.53-3.77 9-1.83 2.47-4.1 4.35-6.8 5.65-2.7 1.3-5.76 1.95-9.16 1.95-4.81 0-8.99-1.29-12.55-3.86-3.55-2.57-6.31-6.26-8.27-11.04-1.96-4.79-2.94-10.52-2.94-17.21 0-6.6.99-12.26 2.97-16.98 1.99-4.74 4.77-8.37 8.34-10.91ZM1066.17 368.36h27.64l-40.25-55.74 38.02-42.33h-27.01l-35.24 39.39h-1.6V237.6h-23.11v130.76h23.11v-32.97l8.41-9.01 30.03 41.98Z\" fill=\"#fff\" fill-rule=\"nonzero\"></path></g>", 1);
const _hoisted_3$6 = [
  _hoisted_2$8
];

function render$8(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$9, _hoisted_3$6))
}

script$9.render = render$8;
script$9.__file = "packages/admin-vue3/src/svg/Logo.vue";

var script$8 = vue.defineComponent({});

const _hoisted_1$8 = { class: "text-white relative w-5 h-4" };
const _hoisted_2$7 = /*#__PURE__*/vue.createElementVNode("div", { class: "absolute left-0 top-0 w-full h-0.5 bg-white" }, null, -1 /* HOISTED */);
const _hoisted_3$5 = /*#__PURE__*/vue.createElementVNode("div", { class: "absolute left-0 top-1/2 w-full h-0.5 bg-white" }, null, -1 /* HOISTED */);
const _hoisted_4$4 = /*#__PURE__*/vue.createElementVNode("div", { class: "absolute left-0 top-full w-full h-0.5 bg-white" }, null, -1 /* HOISTED */);
const _hoisted_5$2 = [
  _hoisted_2$7,
  _hoisted_3$5,
  _hoisted_4$4
];

function render$7(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createElementBlock("button", _hoisted_1$8, _hoisted_5$2))
}

script$8.render = render$7;
script$8.__file = "packages/admin-vue3/src/layouts/default/DefaultLayoutBurger.vue";

var script$7 = vue.defineComponent({
    components: { DefaultLayoutBurger: script$8, Logo: script$9 },
    setup() {
        //
    },
});

const _hoisted_1$7 = { class: "flex items-center pt-2 pb-20 justify-between" };
const _hoisted_2$6 = { class: "flex items-center gap-4" };

function render$6(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Logo = vue.resolveComponent("Logo");
  const _component_DefaultLayoutBurger = vue.resolveComponent("DefaultLayoutBurger");

  return (vue.openBlock(), vue.createElementBlock("header", null, [
    vue.createElementVNode("div", _hoisted_1$7, [
      vue.renderSlot(_ctx.$slots, "logo", {}, () => [
        vue.createVNode(_component_Logo)
      ]),
      vue.createElementVNode("div", _hoisted_2$6, [
        vue.renderSlot(_ctx.$slots, "default", {}, () => [
          vue.createVNode(_component_DefaultLayoutBurger)
        ])
      ])
    ])
  ]))
}

script$7.render = render$6;
script$7.__file = "packages/admin-vue3/src/layouts/default/DefaultLayoutHeader.vue";

const _hoisted_1$6 = { class: "sticky top-0 z-10 h-20 transition-all border-b border-gray-400 bg-gray-50" };
const _hoisted_2$5 = { class: "container flex items-center justify-between h-full px-10" };
const _hoisted_3$4 = { class: "flex items-baseline space-x-4 font-medium text-gray-800" };
const _hoisted_4$3 = { class: "flex space-x-2" };
const _hoisted_5$1 = { class: "container flex items-center justify-end space-x-4 text-sm text-gray-800" };
var script$6 = /*#__PURE__*/ vue.defineComponent({
    setup(__props) {
        vue.ref(false);
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$6, [
                vue.createElementVNode("div", _hoisted_2$5, [
                    vue.createElementVNode("div", _hoisted_3$4, [
                        vue.renderSlot(_ctx.$slots, "topbar-left")
                    ]),
                    vue.createElementVNode("div", _hoisted_4$3, [
                        vue.renderSlot(_ctx.$slots, "topbar-right")
                    ])
                ]),
                vue.createElementVNode("div", _hoisted_5$1, [
                    vue.renderSlot(_ctx.$slots, "topbar-secondary")
                ])
            ]));
        };
    }
});

script$6.__file = "packages/admin-vue3/src/layouts/default/DefaultLayoutTopbar.vue";

var script$5 = vue.defineComponent({
    components: { TransitionSlide: script$a, DefaultLayoutHeader: script$7, DefaultLayoutTopbar: script$6 },
    name: 'Layout',
    setup() {
        const sidebar = vue.reactive({
            isOpen: false,
            show() {
                this.isOpen = true;
            },
            close() {
                this.isOpen = false;
            },
            toggle() {
                this.isOpen = !this.isOpen;
            },
        });
        return {
            sidebar,
        };
    },
});

const _hoisted_1$5 = { class: "flex w-screen h-screen max-h-screen" };
const _hoisted_2$4 = {
  id: "sidebars",
  class: "z-10 flex h-screen shadow"
};
const _hoisted_3$3 = { class: "relative flex flex-col flex-1 h-screen overflow-y-scroll bg-gray-50" };
const _hoisted_4$2 = { class: "relative flex-1 overflow-y-scroll" };

function render$5(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_DefaultLayoutTopbar = vue.resolveComponent("DefaultLayoutTopbar");

  return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$5, [
    vue.createElementVNode("div", _hoisted_2$4, [
      vue.renderSlot(_ctx.$slots, "sidebar-primary", { sidebar: _ctx.sidebar }),
      vue.renderSlot(_ctx.$slots, "sidebar-secondary")
    ]),
    vue.createElementVNode("div", _hoisted_3$3, [
      vue.createElementVNode("main", _hoisted_4$2, [
        vue.createVNode(_component_DefaultLayoutTopbar, null, {
          "topbar-left": vue.withCtx(() => [
            vue.renderSlot(_ctx.$slots, "topbar-left")
          ]),
          "topbar-right": vue.withCtx(() => [
            vue.renderSlot(_ctx.$slots, "topbar-right")
          ]),
          _: 3 /* FORWARDED */
        }),
        vue.renderSlot(_ctx.$slots, "default")
      ])
    ])
  ]))
}

script$5.render = render$5;
script$5.__file = "packages/admin-vue3/src/layouts/default/DefaultLayout.vue";

var script$4 = vue.defineComponent({
    setup() { },
});

const _hoisted_1$4 = { class: "flex w-screen h-screen" };
const _hoisted_2$3 = { class: "grid w-full h-full grid-cols-12" };
const _hoisted_3$2 = { class: "flex flex-col items-center justify-center col-span-12 gap-16 bg-white md:col-span-6" };
const _hoisted_4$1 = { class: "w-full px-12 lg:w-1/2 lg:px-0" };
const _hoisted_5 = { class: "flex items-center justify-center col-span-12 text-white bg-gray-50 md:col-span-6" };

function render$4(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Logo = vue.resolveComponent("Logo");

  return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$4, [
    vue.createElementVNode("div", _hoisted_2$3, [
      vue.createElementVNode("div", _hoisted_3$2, [
        vue.createElementVNode("div", _hoisted_4$1, [
          vue.renderSlot(_ctx.$slots, "default")
        ])
      ]),
      vue.createElementVNode("div", _hoisted_5, [
        vue.createVNode(_component_Logo)
      ])
    ])
  ]))
}

script$4.render = render$4;
script$4.__file = "packages/admin-vue3/src/layouts/guest/GuestLayout.vue";

var script$3 = vue.defineComponent({
    components: { Input: adminVue3.Input, FormField: adminVue3.FormField },
    props: {
        errors: {
            type: [Array, String],
            required: false,
        },
    },
    setup() {
        //
    },
});

const _hoisted_1$3 = { class: "" };

function render$3(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Input = vue.resolveComponent("Input");
  const _component_FormField = vue.resolveComponent("FormField");

  return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$3, [
    vue.createVNode(_component_FormField, {
      errors: _ctx.errors,
      "no-label": ""
    }, {
      default: vue.withCtx(() => [
        vue.createVNode(_component_Input, vue.mergeProps({
          errors: typeof _ctx.errors === 'string' ? [_ctx.errors] : _ctx.errors,
          class: "w-full"
        }, _ctx.$attrs), null, 16 /* FULL_PROPS */, ["errors"])
      ]),
      _: 1 /* STABLE */
    }, 8 /* PROPS */, ["errors"])
  ]))
}

script$3.render = render$3;
script$3.__file = "packages/admin-vue3/src/layouts/guest/GuestLayoutInput.vue";

var script$2 = vue.defineComponent({
    components: { GuestLayout: script$4, Input: script$3, CheckboxSwitch: adminVue3.CheckboxSwitch, Button: adminVue3.Button },
    props: {
        submitRoute: {
            type: String,
            required: true,
        },
        forgotPasswordRoute: {
            type: String,
        },
        lang: {
            type: Object,
            default: {
                login: 'Login',
                email: 'Email',
                password: 'Password',
                remember: 'Remember Me',
                forgot_password: 'Forgot your password?',
            },
        },
    },
    setup({ submitRoute }) {
        const form = macrameVue3.useForm(submitRoute, { email: '', password: '', remember: false }, { method: 'post' });
        return { form };
    },
});

const _hoisted_1$2 = { class: "flex items-center justify-between mt-5" };
const _hoisted_2$2 = { class: "flex items-center justify-center mt-5" };

function render$2(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Input = vue.resolveComponent("Input");
  const _component_CheckboxSwitch = vue.resolveComponent("CheckboxSwitch");
  const _component_Button = vue.resolveComponent("Button");
  const _component_GuestLayout = vue.resolveComponent("GuestLayout");

  return (vue.openBlock(), vue.createBlock(_component_GuestLayout, null, {
    default: vue.withCtx(() => [
      vue.createElementVNode("form", {
        onSubmit: _cache[3] || (_cache[3] = vue.withModifiers((...args) => (_ctx.form.submit && _ctx.form.submit(...args)), ["prevent"]))
      }, [
        vue.createVNode(_component_Input, {
          autofocus: "",
          label: _ctx.lang.email,
          required: "",
          type: "email",
          autocomplete: "username",
          modelValue: _ctx.form.email,
          "onUpdate:modelValue": _cache[0] || (_cache[0] = $event => ((_ctx.form.email) = $event)),
          errors: _ctx.form.errors?.email
        }, null, 8 /* PROPS */, ["label", "modelValue", "errors"]),
        vue.createVNode(_component_Input, {
          required: "",
          type: "password",
          label: _ctx.lang.password,
          autocomplete: "username",
          modelValue: _ctx.form.password,
          "onUpdate:modelValue": _cache[1] || (_cache[1] = $event => ((_ctx.form.password) = $event)),
          errors: _ctx.form.errors?.password
        }, null, 8 /* PROPS */, ["label", "modelValue", "errors"]),
        vue.createElementVNode("div", _hoisted_1$2, [
          vue.createVNode(_component_CheckboxSwitch, {
            sm: "",
            label: _ctx.lang.remember,
            modelValue: _ctx.form.remember,
            "onUpdate:modelValue": _cache[2] || (_cache[2] = $event => ((_ctx.form.remember) = $event)),
            class: "text-sm uppercase"
          }, null, 8 /* PROPS */, ["label", "modelValue"]),
          (_ctx.forgotPasswordRoute)
            ? (vue.openBlock(), vue.createBlock(_component_Button, {
                key: 0,
                href: _ctx.forgotPasswordRoute,
                text: "",
                class: "mt-1 text-right"
              }, {
                default: vue.withCtx(() => [
                  vue.createTextVNode(vue.toDisplayString(_ctx.lang.forgot_password), 1 /* TEXT */)
                ]),
                _: 1 /* STABLE */
              }, 8 /* PROPS */, ["href"]))
            : vue.createCommentVNode("v-if", true)
        ]),
        vue.createElementVNode("div", _hoisted_2$2, [
          vue.createVNode(_component_Button, {
            class: vue.normalizeClass({ 'opacity-25': _ctx.form.processing }),
            disabled: _ctx.form.processing
          }, {
            default: vue.withCtx(() => [
              vue.createTextVNode(vue.toDisplayString(_ctx.lang.login), 1 /* TEXT */)
            ]),
            _: 1 /* STABLE */
          }, 8 /* PROPS */, ["class", "disabled"])
        ])
      ], 32 /* HYDRATE_EVENTS */)
    ]),
    _: 1 /* STABLE */
  }))
}

script$2.render = render$2;
script$2.__file = "packages/admin-vue3/src/pages/Login.vue";

var script$1 = vue.defineComponent({
    components: { GuestLayout: script$4, Input: script$3, Checkbox: script$x, Button: script$P },
    props: {
        submitRoute: {
            type: String,
            required: true,
        },
        lang: {
            type: Object,
            default: {
                message: 'Forgot your password? No problem. Just let us know your email address and we will email you a password reset link that will allow you to choose a new one.',
                email: 'Email',
                send_reset_link: 'Send Password Reset Link',
            },
        },
        status: String,
    },
    setup({ submitRoute }) {
        const form = macrameVue3.useForm(submitRoute, { email: '', password: '', remember: false }, { method: 'post' });
        return { form };
    },
});

const _hoisted_1$1 = { class: "text-sm text-gray-600" };
const _hoisted_2$1 = {
  key: 0,
  class: "mb-4 text-sm font-medium text-green-600"
};
const _hoisted_3$1 = { class: "flex justify-center mt-5" };

function render$1(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Input = vue.resolveComponent("Input");
  const _component_Button = vue.resolveComponent("Button");
  const _component_GuestLayout = vue.resolveComponent("GuestLayout");

  return (vue.openBlock(), vue.createBlock(_component_GuestLayout, null, {
    default: vue.withCtx(() => [
      vue.createElementVNode("div", _hoisted_1$1, vue.toDisplayString(_ctx.lang.message), 1 /* TEXT */),
      (_ctx.status)
        ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_2$1, vue.toDisplayString(_ctx.status), 1 /* TEXT */))
        : vue.createCommentVNode("v-if", true),
      vue.createElementVNode("form", {
        onSubmit: _cache[1] || (_cache[1] = vue.withModifiers((...args) => (_ctx.form.submit && _ctx.form.submit(...args)), ["prevent"]))
      }, [
        vue.createVNode(_component_Input, {
          autofocus: "",
          required: "",
          class: "",
          label: _ctx.lang.email,
          type: "email",
          autocomplete: "username",
          modelValue: _ctx.form.email,
          "onUpdate:modelValue": _cache[0] || (_cache[0] = $event => ((_ctx.form.email) = $event)),
          errors: _ctx.form.errors?.email
        }, null, 8 /* PROPS */, ["label", "modelValue", "errors"]),
        vue.createElementVNode("div", _hoisted_3$1, [
          vue.createVNode(_component_Button, {
            class: vue.normalizeClass({ 'opacity-25': _ctx.form.processing }),
            disabled: _ctx.form.processing
          }, {
            default: vue.withCtx(() => [
              vue.createTextVNode(vue.toDisplayString(_ctx.lang.send_reset_link), 1 /* TEXT */)
            ]),
            _: 1 /* STABLE */
          }, 8 /* PROPS */, ["class", "disabled"])
        ])
      ], 32 /* HYDRATE_EVENTS */)
    ]),
    _: 1 /* STABLE */
  }))
}

script$1.render = render$1;
script$1.__file = "packages/admin-vue3/src/pages/ForgotPassword.vue";

var script = vue.defineComponent({
    components: { GuestLayout: script$4, Input: script$3, Checkbox: script$x, Button: script$P },
    props: {
        submitRoute: {
            type: String,
            required: true,
        },
        email: {
            type: String,
            required: true,
        },
        token: {
            type: String,
            required: true,
        },
        lang: {
            type: Object,
            default: {
                password: 'Password',
                password_confirmation: 'Repeat password',
                email: 'Email',
                reset_password: 'Reset Password',
            },
        },
        status: String,
    },
    setup({ submitRoute, token, email }) {
        const form = macrameVue3.useForm(submitRoute, {
            token: token,
            email: email,
            password: '',
            password_confirmation: '',
        }, {
            method: 'post',
            // onFinish() {
            //     console.log('foo');
            // },
        });
        return { form };
    },
});

const _hoisted_1 = { class: "text-sm text-gray-600" };
const _hoisted_2 = {
  key: 0,
  class: "mb-4 text-sm font-medium text-green-600"
};
const _hoisted_3 = {
  key: 0,
  class: "mb-4 text-red"
};
const _hoisted_4 = { class: "flex justify-center mt-5" };

function render(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Input = vue.resolveComponent("Input");
  const _component_Button = vue.resolveComponent("Button");
  const _component_GuestLayout = vue.resolveComponent("GuestLayout");

  return (vue.openBlock(), vue.createBlock(_component_GuestLayout, null, {
    default: vue.withCtx(() => [
      vue.createElementVNode("div", _hoisted_1, vue.toDisplayString(_ctx.lang.message), 1 /* TEXT */),
      (_ctx.status)
        ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_2, vue.toDisplayString(_ctx.status), 1 /* TEXT */))
        : vue.createCommentVNode("v-if", true),
      vue.createElementVNode("form", {
        onSubmit: _cache[3] || (_cache[3] = vue.withModifiers((...args) => (_ctx.form.submit && _ctx.form.submit(...args)), ["prevent"]))
      }, [
        vue.createVNode(_component_Input, {
          autofocus: "",
          required: "",
          type: "email",
          autocomplete: "username",
          modelValue: _ctx.form.email,
          "onUpdate:modelValue": _cache[0] || (_cache[0] = $event => ((_ctx.form.email) = $event)),
          label: _ctx.lang.email,
          errors: _ctx.form.errors?.email
        }, null, 8 /* PROPS */, ["modelValue", "label", "errors"]),
        vue.createVNode(_component_Input, {
          required: "",
          type: "password",
          autocomplete: "new-password",
          modelValue: _ctx.form.password,
          "onUpdate:modelValue": _cache[1] || (_cache[1] = $event => ((_ctx.form.password) = $event)),
          label: _ctx.lang.password,
          errors: _ctx.form.errors?.password
        }, null, 8 /* PROPS */, ["modelValue", "label", "errors"]),
        vue.createVNode(_component_Input, {
          required: "",
          type: "password",
          autocomplete: "new-password",
          modelValue: _ctx.form.password_confirmation,
          "onUpdate:modelValue": _cache[2] || (_cache[2] = $event => ((_ctx.form.password_confirmation) = $event)),
          label: _ctx.lang.password_confirmation,
          errors: _ctx.form.errors?.password_confirmation
        }, null, 8 /* PROPS */, ["modelValue", "label", "errors"]),
        (_ctx.form.errors?.token)
          ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_3, vue.toDisplayString(_ctx.form.errors.token), 1 /* TEXT */))
          : vue.createCommentVNode("v-if", true),
        vue.createElementVNode("div", _hoisted_4, [
          vue.createVNode(_component_Button, {
            class: vue.normalizeClass({ 'opacity-25': _ctx.form.processing }),
            disabled: _ctx.form.processing
          }, {
            default: vue.withCtx(() => [
              vue.createTextVNode(vue.toDisplayString(_ctx.lang.reset_password), 1 /* TEXT */)
            ]),
            _: 1 /* STABLE */
          }, 8 /* PROPS */, ["class", "disabled"])
        ])
      ], 32 /* HYDRATE_EVENTS */)
    ]),
    _: 1 /* STABLE */
  }))
}

script.render = render;
script.__file = "packages/admin-vue3/src/pages/ResetPassword.vue";

// import Wysiwyg from './ui/Wysiwyg.vue';
const plugin = {
    install(app) {
        app.component('UiCard', script$O);
        app.component('UiToggle', script$N);
        app.component('UiButton', script$P);
        app.component('UiBadge', script$I);
        app.component('UiForm', script$B);
        app.component('UiModal', script$y);
        app.component('UiCheckbox', script$w);
        app.component('UiFormCheckboxes', script$v);
        // app.component('UiFormSelect', FormSelect);
        // app.component('UiFormTextarea', FormTextarea);
        app.component('UiRadioGroup', script$r);
        app.component('UiIndex', script$o);
        app.component('UiInput', script$u);
        app.component('UiSelect', script$m);
        app.component('UiSidebar', script$k);
        app.component('UiPagination', script$q);
        app.component('UiTable', script$d);
        app.component('UiTextarea', script$c);
    },
};
const AuthPages = {
    "Auth/Login": script$2,
    "Auth/ForgotPassword": script$1,
    "Auth/ResetPassword": script,
};
const Pages = { ...AuthPages };

exports.AuthPages = AuthPages;
exports.Badge = script$I;
exports.Button = script$P;
exports.Card = script$O;
exports.Checkbox = script$w;
exports.CheckboxSwitch = script$x;
exports.Chip = script$M;
exports.ChipInput = script$K;
exports.ContextMenu = script$J;
exports.DatePicker = script$t;
exports.DateRange = script$s;
exports.DefaultLayout = script$5;
exports.DefaultLayoutBurger = script$8;
exports.DefaultLayoutHeader = script$7;
exports.Drawer = script$H;
exports.DrawerSection = script$G;
exports.FileUpload = script$L;
exports.Form = script$B;
exports.FormField = script$z;
exports.FormFieldLabel = script$A;
exports.GuestLayout = script$4;
exports.GuestLayoutInput = script$3;
exports.Index = script$o;
exports.Input = script$u;
exports.List = script$n;
exports.Modal = script$y;
exports.Pages = Pages;
exports.Pagination = script$q;
exports.RadioGroup = script$r;
exports.Search = script$p;
exports.Sections = script$l;
exports.Select = script$m;
exports.Sidebar = script$k;
exports.SidebarLink = script$j;
exports.SidebarPrimary = script$h;
exports.SidebarSecondary = script$g;
exports.SidebarSection = script$i;
exports.Tab = script$F;
exports.TabGroup = script$D;
exports.TabList = script$C;
exports.TabPanel = script$E;
exports.Table = script$d;
exports.Td = script$e;
exports.Textarea = script$c;
exports.Th = script$f;
exports.Toggle = script$N;
exports.Tr = script$b;
exports.plugin = plugin;
